Class: ScrapeBadger::BaiduApi

Inherits:
Object
  • Object
show all
Defined in:
lib/scrapebadger/api/baidu_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ BaiduApi

Returns a new instance of BaiduApi.



19
20
21
# File 'lib/scrapebadger/api/baidu_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/scrapebadger/api/baidu_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#baidu_baidu_image_search(query, opts = {}) ⇒ Object

Baidu image search Baidu image search via the acjson JSON API.

Parameters:

  • query (String)

    Search keywords

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    30 images per page (default to 1)

Returns:

  • (Object)


28
29
30
31
# File 'lib/scrapebadger/api/baidu_api.rb', line 28

def baidu_baidu_image_search(query, opts = {})
  data, _status_code, _headers = baidu_baidu_image_search_with_http_info(query, opts)
  data
end

#baidu_baidu_image_search_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Baidu image search Baidu image search via the acjson JSON API.

Parameters:

  • query (String)

    Search keywords

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    30 images per page (default to 1)

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/scrapebadger/api/baidu_api.rb', line 39

def baidu_baidu_image_search_with_http_info(query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BaiduApi.baidu_baidu_image_search ...'
  end
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling BaiduApi.baidu_baidu_image_search"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 50
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling BaiduApi.baidu_baidu_image_search, must be smaller than or equal to 50.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling BaiduApi.baidu_baidu_image_search, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v1/baidu/images'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"BaiduApi.baidu_baidu_image_search",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BaiduApi#baidu_baidu_image_search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#baidu_baidu_news_search(query, opts = {}) ⇒ Object

Baidu news search Baidu news vertical — articles with source, publish date and real URLs.

Parameters:

  • query (String)

    Search keywords

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer) — default: default to 1

Returns:

  • (Object)


103
104
105
106
# File 'lib/scrapebadger/api/baidu_api.rb', line 103

def baidu_baidu_news_search(query, opts = {})
  data, _status_code, _headers = baidu_baidu_news_search_with_http_info(query, opts)
  data
end

#baidu_baidu_news_search_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Baidu news search Baidu news vertical — articles with source, publish date and real URLs.

Parameters:

  • query (String)

    Search keywords

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer) — default: default to 1

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/scrapebadger/api/baidu_api.rb', line 114

def baidu_baidu_news_search_with_http_info(query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BaiduApi.baidu_baidu_news_search ...'
  end
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling BaiduApi.baidu_baidu_news_search"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 76
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling BaiduApi.baidu_baidu_news_search, must be smaller than or equal to 76.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling BaiduApi.baidu_baidu_news_search, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v1/baidu/news'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"BaiduApi.baidu_baidu_news_search",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BaiduApi#baidu_baidu_news_search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#baidu_baidu_scraper_health_check(opts = {}) ⇒ Object

Baidu scraper health check Check health of the Baidu scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


176
177
178
179
# File 'lib/scrapebadger/api/baidu_api.rb', line 176

def baidu_baidu_scraper_health_check(opts = {})
  data, _status_code, _headers = baidu_baidu_scraper_health_check_with_http_info(opts)
  data
end

#baidu_baidu_scraper_health_check_head(opts = {}) ⇒ Object

Baidu scraper health check Check health of the Baidu scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


233
234
235
236
# File 'lib/scrapebadger/api/baidu_api.rb', line 233

def baidu_baidu_scraper_health_check_head(opts = {})
  data, _status_code, _headers = baidu_baidu_scraper_health_check_head_with_http_info(opts)
  data
end

#baidu_baidu_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

Baidu scraper health check Check health of the Baidu scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/scrapebadger/api/baidu_api.rb', line 242

def baidu_baidu_scraper_health_check_head_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BaiduApi.baidu_baidu_scraper_health_check_head ...'
  end
  # resource path
  local_var_path = '/v1/baidu/health'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"BaiduApi.baidu_baidu_scraper_health_check_head",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BaiduApi#baidu_baidu_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#baidu_baidu_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

Baidu scraper health check Check health of the Baidu scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/scrapebadger/api/baidu_api.rb', line 185

def baidu_baidu_scraper_health_check_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BaiduApi.baidu_baidu_scraper_health_check ...'
  end
  # resource path
  local_var_path = '/v1/baidu/health'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"BaiduApi.baidu_baidu_scraper_health_check",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BaiduApi#baidu_baidu_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#baidu_baidu_web_search(query, opts = {}) ⇒ Object

Baidu web search Baidu web SERP — organic results with real target URLs, related searches, total count.

Parameters:

  • query (String)

    Search keywords, e.g. '咖啡机' or 'coffee machine'

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Result page (10 results per page) (default to 1)

  • :num (Integer)

    Results per page (rn) (default to 10)

Returns:

  • (Object)


293
294
295
296
# File 'lib/scrapebadger/api/baidu_api.rb', line 293

def baidu_baidu_web_search(query, opts = {})
  data, _status_code, _headers = baidu_baidu_web_search_with_http_info(query, opts)
  data
end

#baidu_baidu_web_search_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Baidu web search Baidu web SERP — organic results with real target URLs, related searches, total count.

Parameters:

  • query (String)

    Search keywords, e.g. '咖啡机' or 'coffee machine'

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Result page (10 results per page) (default to 1)

  • :num (Integer)

    Results per page (rn) (default to 10)

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/scrapebadger/api/baidu_api.rb', line 305

def baidu_baidu_web_search_with_http_info(query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BaiduApi.baidu_baidu_web_search ...'
  end
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling BaiduApi.baidu_baidu_web_search"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 76
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling BaiduApi.baidu_baidu_web_search, must be smaller than or equal to 76.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling BaiduApi.baidu_baidu_web_search, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'num'].nil? && opts[:'num'] > 50
    fail ArgumentError, 'invalid value for "opts[:"num"]" when calling BaiduApi.baidu_baidu_web_search, must be smaller than or equal to 50.'
  end

  if @api_client.config.client_side_validation && !opts[:'num'].nil? && opts[:'num'] < 1
    fail ArgumentError, 'invalid value for "opts[:"num"]" when calling BaiduApi.baidu_baidu_web_search, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v1/baidu/search'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'num'] = opts[:'num'] if !opts[:'num'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"BaiduApi.baidu_baidu_web_search",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BaiduApi#baidu_baidu_web_search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#baidu_search_suggestions(query, opts = {}) ⇒ Object

Search suggestions Baidu search-box suggestions.

Parameters:

  • query (String)

    Partial search term, e.g. '咖啡' or 'coff'

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


377
378
379
380
# File 'lib/scrapebadger/api/baidu_api.rb', line 377

def baidu_search_suggestions(query, opts = {})
  data, _status_code, _headers = baidu_search_suggestions_with_http_info(query, opts)
  data
end

#baidu_search_suggestions_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Search suggestions Baidu search-box suggestions.

Parameters:

  • query (String)

    Partial search term, e.g. '咖啡' or 'coff'

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/scrapebadger/api/baidu_api.rb', line 387

def baidu_search_suggestions_with_http_info(query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BaiduApi.baidu_search_suggestions ...'
  end
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling BaiduApi.baidu_search_suggestions"
  end
  # resource path
  local_var_path = '/v1/baidu/autocomplete'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"BaiduApi.baidu_search_suggestions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BaiduApi#baidu_search_suggestions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end