Class: ScrapeBadger::BillingLogResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/scrapebadger/models/billing_log_response.rb

Overview

Billing activity log entry.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BillingLogResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/scrapebadger/models/billing_log_response.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ScrapeBadger::BillingLogResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ScrapeBadger::BillingLogResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'monitor_id')
    self.monitor_id = attributes[:'monitor_id']
  else
    self.monitor_id = nil
  end

  if attributes.key?(:'monitor_name')
    self.monitor_name = attributes[:'monitor_name']
  else
    self.monitor_name = nil
  end

  if attributes.key?(:'billed_at')
    self.billed_at = attributes[:'billed_at']
  else
    self.billed_at = nil
  end

  if attributes.key?(:'num_accounts')
    self.num_accounts = attributes[:'num_accounts']
  else
    self.num_accounts = nil
  end

  if attributes.key?(:'credits_deducted')
    self.credits_deducted = attributes[:'credits_deducted']
  else
    self.credits_deducted = nil
  end

  if attributes.key?(:'tier_label')
    self.tier_label = attributes[:'tier_label']
  else
    self.tier_label = nil
  end

  if attributes.key?(:'rate_applied')
    self.rate_applied = attributes[:'rate_applied']
  else
    self.rate_applied = nil
  end
end

Instance Attribute Details

#billed_atObject

Returns the value of attribute billed_at.



25
26
27
# File 'lib/scrapebadger/models/billing_log_response.rb', line 25

def billed_at
  @billed_at
end

#credits_deductedObject

Returns the value of attribute credits_deducted.



29
30
31
# File 'lib/scrapebadger/models/billing_log_response.rb', line 29

def credits_deducted
  @credits_deducted
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/scrapebadger/models/billing_log_response.rb', line 19

def id
  @id
end

#monitor_idObject

Returns the value of attribute monitor_id.



21
22
23
# File 'lib/scrapebadger/models/billing_log_response.rb', line 21

def monitor_id
  @monitor_id
end

#monitor_nameObject

Returns the value of attribute monitor_name.



23
24
25
# File 'lib/scrapebadger/models/billing_log_response.rb', line 23

def monitor_name
  @monitor_name
end

#num_accountsObject

Returns the value of attribute num_accounts.



27
28
29
# File 'lib/scrapebadger/models/billing_log_response.rb', line 27

def num_accounts
  @num_accounts
end

#rate_appliedObject

Returns the value of attribute rate_applied.



33
34
35
# File 'lib/scrapebadger/models/billing_log_response.rb', line 33

def rate_applied
  @rate_applied
end

#tier_labelObject

Returns the value of attribute tier_label.



31
32
33
# File 'lib/scrapebadger/models/billing_log_response.rb', line 31

def tier_label
  @tier_label
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/scrapebadger/models/billing_log_response.rb', line 247

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ScrapeBadger.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/scrapebadger/models/billing_log_response.rb', line 50

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/scrapebadger/models/billing_log_response.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'monitor_id' => :'monitor_id',
    :'monitor_name' => :'monitor_name',
    :'billed_at' => :'billed_at',
    :'num_accounts' => :'num_accounts',
    :'credits_deducted' => :'credits_deducted',
    :'tier_label' => :'tier_label',
    :'rate_applied' => :'rate_applied'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/scrapebadger/models/billing_log_response.rb', line 223

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/scrapebadger/models/billing_log_response.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/scrapebadger/models/billing_log_response.rb', line 55

def self.openapi_types
  {
    :'id' => :'String',
    :'monitor_id' => :'String',
    :'monitor_name' => :'String',
    :'billed_at' => :'Time',
    :'num_accounts' => :'Integer',
    :'credits_deducted' => :'Float',
    :'tier_label' => :'String',
    :'rate_applied' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/scrapebadger/models/billing_log_response.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      monitor_id == o.monitor_id &&
      monitor_name == o.monitor_name &&
      billed_at == o.billed_at &&
      num_accounts == o.num_accounts &&
      credits_deducted == o.credits_deducted &&
      tier_label == o.tier_label &&
      rate_applied == o.rate_applied
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/scrapebadger/models/billing_log_response.rb', line 318

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/scrapebadger/models/billing_log_response.rb', line 210

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



216
217
218
# File 'lib/scrapebadger/models/billing_log_response.rb', line 216

def hash
  [id, monitor_id, monitor_name, billed_at, num_accounts, credits_deducted, tier_label, rate_applied].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/scrapebadger/models/billing_log_response.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @monitor_id.nil?
    invalid_properties.push('invalid value for "monitor_id", monitor_id cannot be nil.')
  end

  if @monitor_name.nil?
    invalid_properties.push('invalid value for "monitor_name", monitor_name cannot be nil.')
  end

  if @billed_at.nil?
    invalid_properties.push('invalid value for "billed_at", billed_at cannot be nil.')
  end

  if @num_accounts.nil?
    invalid_properties.push('invalid value for "num_accounts", num_accounts cannot be nil.')
  end

  if @credits_deducted.nil?
    invalid_properties.push('invalid value for "credits_deducted", credits_deducted cannot be nil.')
  end

  if @tier_label.nil?
    invalid_properties.push('invalid value for "tier_label", tier_label cannot be nil.')
  end

  if @rate_applied.nil?
    invalid_properties.push('invalid value for "rate_applied", rate_applied cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
# File 'lib/scrapebadger/models/billing_log_response.rb', line 294

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/scrapebadger/models/billing_log_response.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



288
289
290
# File 'lib/scrapebadger/models/billing_log_response.rb', line 288

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/scrapebadger/models/billing_log_response.rb', line 180

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @monitor_id.nil?
  return false if @monitor_name.nil?
  return false if @billed_at.nil?
  return false if @num_accounts.nil?
  return false if @credits_deducted.nil?
  return false if @tier_label.nil?
  return false if @rate_applied.nil?
  true
end