Class: ScrapeBadger::DepopApi
- Inherits:
-
Object
- Object
- ScrapeBadger::DepopApi
- Defined in:
- lib/scrapebadger/api/depop_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#depop_depop_scraper_health_check(opts = {}) ⇒ Object
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
-
#depop_depop_scraper_health_check_head(opts = {}) ⇒ Object
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
-
#depop_depop_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
-
#depop_depop_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
-
#depop_get_a_user_s_products(username, opts = {}) ⇒ Object
Get a user's products A user's active listings (cursor-paginated).
-
#depop_get_a_user_s_products_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get a user's products A user's active listings (cursor-paginated).
-
#depop_get_product_detail(product_id, opts = {}) ⇒ Object
Get product detail Full detail for a single product (by numeric id or slug).
-
#depop_get_product_detail_with_http_info(product_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get product detail Full detail for a single product (by numeric id or slug).
-
#depop_get_shop_user_profile(username, opts = {}) ⇒ Object
Get shop/user profile Public shop/user profile by username.
-
#depop_get_shop_user_profile_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get shop/user profile Public shop/user profile by username.
-
#depop_list_markets(opts = {}) ⇒ Object
List markets List supported Depop markets (country + currency).
-
#depop_list_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List markets List supported Depop markets (country + currency).
-
#depop_search_depop_products(query, opts = {}) ⇒ Object
Search Depop products Search the Depop catalog with filters (cursor-paginated).
-
#depop_search_depop_products_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search Depop products Search the Depop catalog with filters (cursor-paginated).
-
#initialize(api_client = ApiClient.default) ⇒ DepopApi
constructor
A new instance of DepopApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/scrapebadger/api/depop_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#depop_depop_scraper_health_check(opts = {}) ⇒ Object
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
26 27 28 29 |
# File 'lib/scrapebadger/api/depop_api.rb', line 26 def depop_depop_scraper_health_check(opts = {}) data, _status_code, _headers = depop_depop_scraper_health_check_with_http_info(opts) data end |
#depop_depop_scraper_health_check_head(opts = {}) ⇒ Object
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
83 84 85 86 |
# File 'lib/scrapebadger/api/depop_api.rb', line 83 def depop_depop_scraper_health_check_head(opts = {}) data, _status_code, _headers = depop_depop_scraper_health_check_head_with_http_info(opts) data end |
#depop_depop_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/scrapebadger/api/depop_api.rb', line 92 def depop_depop_scraper_health_check_head_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DepopApi.depop_depop_scraper_health_check_head ...' end # resource path local_var_path = '/v1/depop/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DepopApi.depop_depop_scraper_health_check_head", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DepopApi#depop_depop_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#depop_depop_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Depop scraper health check Check health of the Depop scraper service (accepts HEAD).
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/scrapebadger/api/depop_api.rb', line 35 def depop_depop_scraper_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DepopApi.depop_depop_scraper_health_check ...' end # resource path local_var_path = '/v1/depop/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DepopApi.depop_depop_scraper_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DepopApi#depop_depop_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#depop_get_a_user_s_products(username, opts = {}) ⇒ Object
Get a user's products A user's active listings (cursor-paginated).
144 145 146 147 |
# File 'lib/scrapebadger/api/depop_api.rb', line 144 def depop_get_a_user_s_products(username, opts = {}) data, _status_code, _headers = depop_get_a_user_s_products_with_http_info(username, opts) data end |
#depop_get_a_user_s_products_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get a user's products A user's active listings (cursor-paginated).
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/scrapebadger/api/depop_api.rb', line 157 def depop_get_a_user_s_products_with_http_info(username, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DepopApi.depop_get_a_user_s_products ...' end # verify the required parameter 'username' is set if @api_client.config.client_side_validation && username.nil? fail ArgumentError, "Missing the required parameter 'username' when calling DepopApi.depop_get_a_user_s_products" end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 100 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling DepopApi.depop_get_a_user_s_products, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling DepopApi.depop_get_a_user_s_products, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/depop/users/{username}/products'.sub('{' + 'username' + '}', CGI.escape(username.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DepopApi.depop_get_a_user_s_products", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DepopApi#depop_get_a_user_s_products\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#depop_get_product_detail(product_id, opts = {}) ⇒ Object
Get product detail Full detail for a single product (by numeric id or slug).
222 223 224 225 |
# File 'lib/scrapebadger/api/depop_api.rb', line 222 def depop_get_product_detail(product_id, opts = {}) data, _status_code, _headers = depop_get_product_detail_with_http_info(product_id, opts) data end |
#depop_get_product_detail_with_http_info(product_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get product detail Full detail for a single product (by numeric id or slug).
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/scrapebadger/api/depop_api.rb', line 233 def depop_get_product_detail_with_http_info(product_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DepopApi.depop_get_product_detail ...' end # verify the required parameter 'product_id' is set if @api_client.config.client_side_validation && product_id.nil? fail ArgumentError, "Missing the required parameter 'product_id' when calling DepopApi.depop_get_product_detail" end # resource path local_var_path = '/v1/depop/products/{product_id}'.sub('{' + 'product_id' + '}', CGI.escape(product_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DepopApi.depop_get_product_detail", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DepopApi#depop_get_product_detail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#depop_get_shop_user_profile(username, opts = {}) ⇒ Object
Get shop/user profile Public shop/user profile by username.
288 289 290 291 |
# File 'lib/scrapebadger/api/depop_api.rb', line 288 def depop_get_shop_user_profile(username, opts = {}) data, _status_code, _headers = depop_get_shop_user_profile_with_http_info(username, opts) data end |
#depop_get_shop_user_profile_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get shop/user profile Public shop/user profile by username.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/scrapebadger/api/depop_api.rb', line 299 def depop_get_shop_user_profile_with_http_info(username, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DepopApi.depop_get_shop_user_profile ...' end # verify the required parameter 'username' is set if @api_client.config.client_side_validation && username.nil? fail ArgumentError, "Missing the required parameter 'username' when calling DepopApi.depop_get_shop_user_profile" end # resource path local_var_path = '/v1/depop/users/{username}'.sub('{' + 'username' + '}', CGI.escape(username.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DepopApi.depop_get_shop_user_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DepopApi#depop_get_shop_user_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#depop_list_markets(opts = {}) ⇒ Object
List markets List supported Depop markets (country + currency).
352 353 354 355 |
# File 'lib/scrapebadger/api/depop_api.rb', line 352 def depop_list_markets(opts = {}) data, _status_code, _headers = depop_list_markets_with_http_info(opts) data end |
#depop_list_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List markets List supported Depop markets (country + currency).
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/scrapebadger/api/depop_api.rb', line 361 def depop_list_markets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DepopApi.depop_list_markets ...' end # resource path local_var_path = '/v1/depop/markets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DepopApi.depop_list_markets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DepopApi#depop_list_markets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#depop_search_depop_products(query, opts = {}) ⇒ Object
Search Depop products Search the Depop catalog with filters (cursor-paginated).
421 422 423 424 |
# File 'lib/scrapebadger/api/depop_api.rb', line 421 def depop_search_depop_products(query, opts = {}) data, _status_code, _headers = depop_search_depop_products_with_http_info(query, opts) data end |
#depop_search_depop_products_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search Depop products Search the Depop catalog with filters (cursor-paginated).
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/scrapebadger/api/depop_api.rb', line 442 def depop_search_depop_products_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DepopApi.depop_search_depop_products ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling DepopApi.depop_search_depop_products" end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 100 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling DepopApi.depop_search_depop_products, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling DepopApi.depop_search_depop_products, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'price_min'].nil? && opts[:'price_min'] < 0 fail ArgumentError, 'invalid value for "opts[:"price_min"]" when calling DepopApi.depop_search_depop_products, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'price_max'].nil? && opts[:'price_max'] < 0 fail ArgumentError, 'invalid value for "opts[:"price_max"]" when calling DepopApi.depop_search_depop_products, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/depop/search' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'price_min'] = opts[:'price_min'] if !opts[:'price_min'].nil? query_params[:'price_max'] = opts[:'price_max'] if !opts[:'price_max'].nil? query_params[:'brands'] = opts[:'brands'] if !opts[:'brands'].nil? query_params[:'categories'] = opts[:'categories'] if !opts[:'categories'].nil? query_params[:'sizes'] = opts[:'sizes'] if !opts[:'sizes'].nil? query_params[:'conditions'] = opts[:'conditions'] if !opts[:'conditions'].nil? query_params[:'gender'] = opts[:'gender'] if !opts[:'gender'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DepopApi.depop_search_depop_products", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DepopApi#depop_search_depop_products\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |