Class: ScrapeBadger::EBayApi
- Inherits:
-
Object
- Object
- ScrapeBadger::EBayApi
- Defined in:
- lib/scrapebadger/api/e_bay_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#ebay_browse_a_category(category_id, opts = {}) ⇒ Object
Browse a category List active listings within an eBay category.
-
#ebay_browse_a_category_with_http_info(category_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Browse a category List active listings within an eBay category.
-
#ebay_completed_sold_listings(query, opts = {}) ⇒ Object
Completed / sold listings Search completed/sold listings — eBay's sold-price history.
-
#ebay_completed_sold_listings_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Completed / sold listings Search completed/sold listings — eBay's sold-price history.
-
#ebay_ebay_scraper_health_check(opts = {}) ⇒ Object
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
-
#ebay_ebay_scraper_health_check_head(opts = {}) ⇒ Object
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
-
#ebay_ebay_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
-
#ebay_ebay_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
-
#ebay_get_item_detail(item_id, opts = {}) ⇒ Object
Get item detail Get a single eBay listing's full detail.
-
#ebay_get_item_detail_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get item detail Get a single eBay listing's full detail.
-
#ebay_get_item_reviews(item_id, opts = {}) ⇒ Object
Get item reviews Get catalog product reviews shown on an eBay listing.
-
#ebay_get_item_reviews_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get item reviews Get catalog product reviews shown on an eBay listing.
-
#ebay_get_seller_feedback(username, opts = {}) ⇒ Object
Get seller feedback Get a seller's recent feedback comments.
-
#ebay_get_seller_feedback_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller feedback Get a seller's recent feedback comments.
-
#ebay_get_seller_listings(username, opts = {}) ⇒ Object
Get seller listings List the active listings of a single eBay seller.
-
#ebay_get_seller_listings_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller listings List the active listings of a single eBay seller.
-
#ebay_get_seller_profile(username, opts = {}) ⇒ Object
Get seller profile Get an eBay seller's public profile.
-
#ebay_get_seller_profile_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller profile Get an eBay seller's public profile.
-
#ebay_keyword_suggestions(query, opts = {}) ⇒ Object
Keyword suggestions Return eBay keyword autocomplete suggestions.
-
#ebay_keyword_suggestions_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Keyword suggestions Return eBay keyword autocomplete suggestions.
-
#ebay_list_categories(opts = {}) ⇒ Object
List categories List eBay's top-level category ids.
-
#ebay_list_categories_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List categories List eBay's top-level category ids.
-
#ebay_list_markets(opts = {}) ⇒ Object
List markets List all supported eBay marketplaces.
-
#ebay_list_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List markets List all supported eBay marketplaces.
-
#ebay_search_listings(query, opts = {}) ⇒ Object
Search listings Search an eBay marketplace for active listings.
-
#ebay_search_listings_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search listings Search an eBay marketplace for active listings.
-
#initialize(api_client = ApiClient.default) ⇒ EBayApi
constructor
A new instance of EBayApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#ebay_browse_a_category(category_id, opts = {}) ⇒ Object
Browse a category List active listings within an eBay category.
33 34 35 36 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 33 def ebay_browse_a_category(category_id, opts = {}) data, _status_code, _headers = ebay_browse_a_category_with_http_info(category_id, opts) data end |
#ebay_browse_a_category_with_http_info(category_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Browse a category List active listings within an eBay category.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 49 def ebay_browse_a_category_with_http_info(category_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_browse_a_category ...' end # verify the required parameter 'category_id' is set if @api_client.config.client_side_validation && category_id.nil? fail ArgumentError, "Missing the required parameter 'category_id' when calling EBayApi.ebay_browse_a_category" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 100 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_browse_a_category, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_browse_a_category, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 240 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_browse_a_category, must be smaller than or equal to 240.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_browse_a_category, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling EBayApi.ebay_browse_a_category, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling EBayApi.ebay_browse_a_category, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/ebay/categories/{category_id}/items'.sub('{' + 'category_id' + '}', CGI.escape(category_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil? query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_browse_a_category", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_browse_a_category\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_completed_sold_listings(query, opts = {}) ⇒ Object
Completed / sold listings Search completed/sold listings — eBay's sold-price history.
140 141 142 143 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 140 def ebay_completed_sold_listings(query, opts = {}) data, _status_code, _headers = ebay_completed_sold_listings_with_http_info(query, opts) data end |
#ebay_completed_sold_listings_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Completed / sold listings Search completed/sold listings — eBay's sold-price history.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 158 def ebay_completed_sold_listings_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_completed_sold_listings ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling EBayApi.ebay_completed_sold_listings" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 100 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_completed_sold_listings, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_completed_sold_listings, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 240 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_completed_sold_listings, must be smaller than or equal to 240.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_completed_sold_listings, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling EBayApi.ebay_completed_sold_listings, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling EBayApi.ebay_completed_sold_listings, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/ebay/completed' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'category_id'] = opts[:'category_id'] if !opts[:'category_id'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'condition'] = opts[:'condition'] if !opts[:'condition'].nil? query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil? query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_completed_sold_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_completed_sold_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_ebay_scraper_health_check(opts = {}) ⇒ Object
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
243 244 245 246 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 243 def ebay_ebay_scraper_health_check(opts = {}) data, _status_code, _headers = ebay_ebay_scraper_health_check_with_http_info(opts) data end |
#ebay_ebay_scraper_health_check_head(opts = {}) ⇒ Object
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
300 301 302 303 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 300 def ebay_ebay_scraper_health_check_head(opts = {}) data, _status_code, _headers = ebay_ebay_scraper_health_check_head_with_http_info(opts) data end |
#ebay_ebay_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 309 def ebay_ebay_scraper_health_check_head_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_ebay_scraper_health_check_head ...' end # resource path local_var_path = '/v1/ebay/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_ebay_scraper_health_check_head", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_ebay_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_ebay_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
eBay scraper health check Check health of the eBay scraper service (accepts HEAD for UptimeRobot).
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 252 def ebay_ebay_scraper_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_ebay_scraper_health_check ...' end # resource path local_var_path = '/v1/ebay/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_ebay_scraper_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_ebay_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_get_item_detail(item_id, opts = {}) ⇒ Object
Get item detail Get a single eBay listing's full detail.
359 360 361 362 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 359 def ebay_get_item_detail(item_id, opts = {}) data, _status_code, _headers = ebay_get_item_detail_with_http_info(item_id, opts) data end |
#ebay_get_item_detail_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get item detail Get a single eBay listing's full detail.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 370 def ebay_get_item_detail_with_http_info(item_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_get_item_detail ...' end # verify the required parameter 'item_id' is set if @api_client.config.client_side_validation && item_id.nil? fail ArgumentError, "Missing the required parameter 'item_id' when calling EBayApi.ebay_get_item_detail" end # resource path local_var_path = '/v1/ebay/items/{item_id}'.sub('{' + 'item_id' + '}', CGI.escape(item_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_get_item_detail", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_get_item_detail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_get_item_reviews(item_id, opts = {}) ⇒ Object
Get item reviews Get catalog product reviews shown on an eBay listing.
426 427 428 429 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 426 def ebay_get_item_reviews(item_id, opts = {}) data, _status_code, _headers = ebay_get_item_reviews_with_http_info(item_id, opts) data end |
#ebay_get_item_reviews_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get item reviews Get catalog product reviews shown on an eBay listing.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 438 def ebay_get_item_reviews_with_http_info(item_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_get_item_reviews ...' end # verify the required parameter 'item_id' is set if @api_client.config.client_side_validation && item_id.nil? fail ArgumentError, "Missing the required parameter 'item_id' when calling EBayApi.ebay_get_item_reviews" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 50 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_get_item_reviews, must be smaller than or equal to 50.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_get_item_reviews, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/ebay/items/{item_id}/reviews'.sub('{' + 'item_id' + '}', CGI.escape(item_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_get_item_reviews", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_get_item_reviews\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_get_seller_feedback(username, opts = {}) ⇒ Object
Get seller feedback Get a seller's recent feedback comments.
503 504 505 506 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 503 def ebay_get_seller_feedback(username, opts = {}) data, _status_code, _headers = ebay_get_seller_feedback_with_http_info(username, opts) data end |
#ebay_get_seller_feedback_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller feedback Get a seller's recent feedback comments.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 515 def ebay_get_seller_feedback_with_http_info(username, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_get_seller_feedback ...' end # verify the required parameter 'username' is set if @api_client.config.client_side_validation && username.nil? fail ArgumentError, "Missing the required parameter 'username' when calling EBayApi.ebay_get_seller_feedback" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 50 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_get_seller_feedback, must be smaller than or equal to 50.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_get_seller_feedback, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/ebay/sellers/{username}/feedback'.sub('{' + 'username' + '}', CGI.escape(username.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_get_seller_feedback", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_get_seller_feedback\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_get_seller_listings(username, opts = {}) ⇒ Object
Get seller listings List the active listings of a single eBay seller.
582 583 584 585 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 582 def ebay_get_seller_listings(username, opts = {}) data, _status_code, _headers = ebay_get_seller_listings_with_http_info(username, opts) data end |
#ebay_get_seller_listings_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller listings List the active listings of a single eBay seller.
596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 596 def ebay_get_seller_listings_with_http_info(username, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_get_seller_listings ...' end # verify the required parameter 'username' is set if @api_client.config.client_side_validation && username.nil? fail ArgumentError, "Missing the required parameter 'username' when calling EBayApi.ebay_get_seller_listings" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 100 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_get_seller_listings, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_get_seller_listings, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 240 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_get_seller_listings, must be smaller than or equal to 240.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_get_seller_listings, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/ebay/sellers/{username}/items'.sub('{' + 'username' + '}', CGI.escape(username.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'query'] = opts[:'query'] if !opts[:'query'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_get_seller_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_get_seller_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_get_seller_profile(username, opts = {}) ⇒ Object
Get seller profile Get an eBay seller's public profile.
670 671 672 673 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 670 def ebay_get_seller_profile(username, opts = {}) data, _status_code, _headers = ebay_get_seller_profile_with_http_info(username, opts) data end |
#ebay_get_seller_profile_with_http_info(username, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller profile Get an eBay seller's public profile.
681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 681 def ebay_get_seller_profile_with_http_info(username, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_get_seller_profile ...' end # verify the required parameter 'username' is set if @api_client.config.client_side_validation && username.nil? fail ArgumentError, "Missing the required parameter 'username' when calling EBayApi.ebay_get_seller_profile" end # resource path local_var_path = '/v1/ebay/sellers/{username}'.sub('{' + 'username' + '}', CGI.escape(username.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_get_seller_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_get_seller_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_keyword_suggestions(query, opts = {}) ⇒ Object
Keyword suggestions Return eBay keyword autocomplete suggestions.
736 737 738 739 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 736 def ebay_keyword_suggestions(query, opts = {}) data, _status_code, _headers = ebay_keyword_suggestions_with_http_info(query, opts) data end |
#ebay_keyword_suggestions_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Keyword suggestions Return eBay keyword autocomplete suggestions.
747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 747 def ebay_keyword_suggestions_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_keyword_suggestions ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling EBayApi.ebay_keyword_suggestions" end # resource path local_var_path = '/v1/ebay/autocomplete' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_keyword_suggestions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_keyword_suggestions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_list_categories(opts = {}) ⇒ Object
List categories List eBay's top-level category ids.
801 802 803 804 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 801 def ebay_list_categories(opts = {}) data, _status_code, _headers = ebay_list_categories_with_http_info(opts) data end |
#ebay_list_categories_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List categories List eBay's top-level category ids.
810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 810 def ebay_list_categories_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_list_categories ...' end # resource path local_var_path = '/v1/ebay/categories' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_list_categories", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_list_categories\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_list_markets(opts = {}) ⇒ Object
List markets List all supported eBay marketplaces.
858 859 860 861 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 858 def ebay_list_markets(opts = {}) data, _status_code, _headers = ebay_list_markets_with_http_info(opts) data end |
#ebay_list_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List markets List all supported eBay marketplaces.
867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 867 def ebay_list_markets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_list_markets ...' end # resource path local_var_path = '/v1/ebay/markets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_list_markets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_list_markets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ebay_search_listings(query, opts = {}) ⇒ Object
Search listings Search an eBay marketplace for active listings.
926 927 928 929 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 926 def ebay_search_listings(query, opts = {}) data, _status_code, _headers = ebay_search_listings_with_http_info(query, opts) data end |
#ebay_search_listings_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search listings Search an eBay marketplace for active listings.
946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 |
# File 'lib/scrapebadger/api/e_bay_api.rb', line 946 def ebay_search_listings_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EBayApi.ebay_search_listings ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling EBayApi.ebay_search_listings" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 100 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_search_listings, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling EBayApi.ebay_search_listings, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 240 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_search_listings, must be smaller than or equal to 240.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling EBayApi.ebay_search_listings, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling EBayApi.ebay_search_listings, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling EBayApi.ebay_search_listings, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/ebay/search' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'category_id'] = opts[:'category_id'] if !opts[:'category_id'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'condition'] = opts[:'condition'] if !opts[:'condition'].nil? query_params[:'buying_format'] = opts[:'buying_format'] if !opts[:'buying_format'].nil? query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil? query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil? query_params[:'free_shipping'] = opts[:'free_shipping'] if !opts[:'free_shipping'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EBayApi.ebay_search_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EBayApi#ebay_search_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |