Class: ScrapeBadger::FilterRuleCreate

Inherits:
Object
  • Object
show all
Defined in:
lib/scrapebadger/models/filter_rule_create.rb

Overview

Create filter rule request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FilterRuleCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ScrapeBadger::FilterRuleCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ScrapeBadger::FilterRuleCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  else
    self.tag = nil
  end

  if attributes.key?(:'query')
    self.query = attributes[:'query']
  else
    self.query = nil
  end

  if attributes.key?(:'interval_seconds')
    self.interval_seconds = attributes[:'interval_seconds']
  else
    self.interval_seconds = nil
  end

  if attributes.key?(:'max_results_per_poll')
    self.max_results_per_poll = attributes[:'max_results_per_poll']
  else
    self.max_results_per_poll = 20
  end

  if attributes.key?(:'webhook_url')
    self.webhook_url = attributes[:'webhook_url']
  end

  if attributes.key?(:'webhook_secret')
    self.webhook_secret = attributes[:'webhook_secret']
  end
end

Instance Attribute Details

#interval_secondsObject

Returns the value of attribute interval_seconds.



23
24
25
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 23

def interval_seconds
  @interval_seconds
end

#max_results_per_pollObject

Returns the value of attribute max_results_per_poll.



25
26
27
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 25

def max_results_per_poll
  @max_results_per_poll
end

#queryObject

Returns the value of attribute query.



21
22
23
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 21

def query
  @query
end

#tagObject

Returns the value of attribute tag.



19
20
21
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 19

def tag
  @tag
end

#webhook_secretObject

Returns the value of attribute webhook_secret.



29
30
31
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 29

def webhook_secret
  @webhook_secret
end

#webhook_urlObject

Returns the value of attribute webhook_url.



27
28
29
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 27

def webhook_url
  @webhook_url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 340

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ScrapeBadger.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 44

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 32

def self.attribute_map
  {
    :'tag' => :'tag',
    :'query' => :'query',
    :'interval_seconds' => :'interval_seconds',
    :'max_results_per_poll' => :'max_results_per_poll',
    :'webhook_url' => :'webhook_url',
    :'webhook_secret' => :'webhook_secret'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 316

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
65
66
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 61

def self.openapi_nullable
  Set.new([
    :'webhook_url',
    :'webhook_secret'
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 49

def self.openapi_types
  {
    :'tag' => :'String',
    :'query' => :'String',
    :'interval_seconds' => :'Float',
    :'max_results_per_poll' => :'Integer',
    :'webhook_url' => :'String',
    :'webhook_secret' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tag == o.tag &&
      query == o.query &&
      interval_seconds == o.interval_seconds &&
      max_results_per_poll == o.max_results_per_poll &&
      webhook_url == o.webhook_url &&
      webhook_secret == o.webhook_secret
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 411

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


303
304
305
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 303

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



309
310
311
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 309

def hash
  [tag, query, interval_seconds, max_results_per_poll, webhook_url, webhook_secret].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @tag.nil?
    invalid_properties.push('invalid value for "tag", tag cannot be nil.')
  end

  if @tag.to_s.length > 100
    invalid_properties.push('invalid value for "tag", the character length must be smaller than or equal to 100.')
  end

  if @tag.to_s.length < 1
    invalid_properties.push('invalid value for "tag", the character length must be great than or equal to 1.')
  end

  if @query.nil?
    invalid_properties.push('invalid value for "query", query cannot be nil.')
  end

  if @query.to_s.length > 1024
    invalid_properties.push('invalid value for "query", the character length must be smaller than or equal to 1024.')
  end

  if @query.to_s.length < 1
    invalid_properties.push('invalid value for "query", the character length must be great than or equal to 1.')
  end

  if @interval_seconds.nil?
    invalid_properties.push('invalid value for "interval_seconds", interval_seconds cannot be nil.')
  end

  if @interval_seconds > 86400.0
    invalid_properties.push('invalid value for "interval_seconds", must be smaller than or equal to 86400.0.')
  end

  if @interval_seconds < 0.1
    invalid_properties.push('invalid value for "interval_seconds", must be greater than or equal to 0.1.')
  end

  if !@max_results_per_poll.nil? && @max_results_per_poll > 100
    invalid_properties.push('invalid value for "max_results_per_poll", must be smaller than or equal to 100.')
  end

  if !@max_results_per_poll.nil? && @max_results_per_poll < 1
    invalid_properties.push('invalid value for "max_results_per_poll", must be greater than or equal to 1.')
  end

  if !@webhook_url.nil? && @webhook_url.to_s.length > 2048
    invalid_properties.push('invalid value for "webhook_url", the character length must be smaller than or equal to 2048.')
  end

  if !@webhook_secret.nil? && @webhook_secret.to_s.length > 128
    invalid_properties.push('invalid value for "webhook_secret", the character length must be smaller than or equal to 128.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



387
388
389
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 387

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



381
382
383
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 381

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/scrapebadger/models/filter_rule_create.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @tag.nil?
  return false if @tag.to_s.length > 100
  return false if @tag.to_s.length < 1
  return false if @query.nil?
  return false if @query.to_s.length > 1024
  return false if @query.to_s.length < 1
  return false if @interval_seconds.nil?
  return false if @interval_seconds > 86400.0
  return false if @interval_seconds < 0.1
  return false if !@max_results_per_poll.nil? && @max_results_per_poll > 100
  return false if !@max_results_per_poll.nil? && @max_results_per_poll < 1
  return false if !@webhook_url.nil? && @webhook_url.to_s.length > 2048
  return false if !@webhook_secret.nil? && @webhook_secret.to_s.length > 128
  true
end