Class: ScrapeBadger::FilterRuleDeliveryLogResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/scrapebadger/models/filter_rule_delivery_log_response.rb

Overview

Delivery log entry for a filter rule.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FilterRuleDeliveryLogResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ScrapeBadger::FilterRuleDeliveryLogResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ScrapeBadger::FilterRuleDeliveryLogResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'rule_id')
    self.rule_id = attributes[:'rule_id']
  else
    self.rule_id = nil
  end

  if attributes.key?(:'rule_tag')
    self.rule_tag = attributes[:'rule_tag']
  else
    self.rule_tag = nil
  end

  if attributes.key?(:'tweet_id')
    self.tweet_id = attributes[:'tweet_id']
  else
    self.tweet_id = nil
  end

  if attributes.key?(:'author_username')
    self.author_username = attributes[:'author_username']
  else
    self.author_username = nil
  end

  if attributes.key?(:'tweet_text_preview')
    self.tweet_text_preview = attributes[:'tweet_text_preview']
  else
    self.tweet_text_preview = nil
  end

  if attributes.key?(:'tweet_url')
    self.tweet_url = attributes[:'tweet_url']
  else
    self.tweet_url = nil
  end

  if attributes.key?(:'tweet_published_at')
    self.tweet_published_at = attributes[:'tweet_published_at']
  else
    self.tweet_published_at = nil
  end

  if attributes.key?(:'detected_at')
    self.detected_at = attributes[:'detected_at']
  else
    self.detected_at = nil
  end

  if attributes.key?(:'latency_ms')
    self.latency_ms = attributes[:'latency_ms']
  else
    self.latency_ms = nil
  end

  if attributes.key?(:'latency_badge')
    self.latency_badge = attributes[:'latency_badge']
  else
    self.latency_badge = nil
  end

  if attributes.key?(:'delivery_status')
    self.delivery_status = attributes[:'delivery_status']
  else
    self.delivery_status = nil
  end

  if attributes.key?(:'webhook_status_code')
    self.webhook_status_code = attributes[:'webhook_status_code']
  else
    self.webhook_status_code = nil
  end

  if attributes.key?(:'webhook_attempts')
    self.webhook_attempts = attributes[:'webhook_attempts']
  else
    self.webhook_attempts = nil
  end
end

Instance Attribute Details

#author_usernameObject

Returns the value of attribute author_username.



27
28
29
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 27

def author_username
  @author_username
end

#delivery_statusObject

Returns the value of attribute delivery_status.



41
42
43
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 41

def delivery_status
  @delivery_status
end

#detected_atObject

Returns the value of attribute detected_at.



35
36
37
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 35

def detected_at
  @detected_at
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 19

def id
  @id
end

#latency_badgeObject

Returns the value of attribute latency_badge.



39
40
41
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 39

def latency_badge
  @latency_badge
end

#latency_msObject

Returns the value of attribute latency_ms.



37
38
39
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 37

def latency_ms
  @latency_ms
end

#rule_idObject

Returns the value of attribute rule_id.



21
22
23
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 21

def rule_id
  @rule_id
end

#rule_tagObject

Returns the value of attribute rule_tag.



23
24
25
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 23

def rule_tag
  @rule_tag
end

#tweet_idObject

Returns the value of attribute tweet_id.



25
26
27
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 25

def tweet_id
  @tweet_id
end

#tweet_published_atObject

Returns the value of attribute tweet_published_at.



33
34
35
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 33

def tweet_published_at
  @tweet_published_at
end

#tweet_text_previewObject

Returns the value of attribute tweet_text_preview.



29
30
31
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 29

def tweet_text_preview
  @tweet_text_preview
end

#tweet_urlObject

Returns the value of attribute tweet_url.



31
32
33
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 31

def tweet_url
  @tweet_url
end

#webhook_attemptsObject

Returns the value of attribute webhook_attempts.



45
46
47
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 45

def webhook_attempts
  @webhook_attempts
end

#webhook_status_codeObject

Returns the value of attribute webhook_status_code.



43
44
45
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 43

def webhook_status_code
  @webhook_status_code
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 335

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ScrapeBadger.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 48

def self.attribute_map
  {
    :'id' => :'id',
    :'rule_id' => :'rule_id',
    :'rule_tag' => :'rule_tag',
    :'tweet_id' => :'tweet_id',
    :'author_username' => :'author_username',
    :'tweet_text_preview' => :'tweet_text_preview',
    :'tweet_url' => :'tweet_url',
    :'tweet_published_at' => :'tweet_published_at',
    :'detected_at' => :'detected_at',
    :'latency_ms' => :'latency_ms',
    :'latency_badge' => :'latency_badge',
    :'delivery_status' => :'delivery_status',
    :'webhook_status_code' => :'webhook_status_code',
    :'webhook_attempts' => :'webhook_attempts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 93

def self.openapi_nullable
  Set.new([
    :'tweet_text_preview',
    :'webhook_status_code',
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 73

def self.openapi_types
  {
    :'id' => :'String',
    :'rule_id' => :'String',
    :'rule_tag' => :'String',
    :'tweet_id' => :'String',
    :'author_username' => :'String',
    :'tweet_text_preview' => :'String',
    :'tweet_url' => :'String',
    :'tweet_published_at' => :'Time',
    :'detected_at' => :'Time',
    :'latency_ms' => :'Integer',
    :'latency_badge' => :'String',
    :'delivery_status' => :'String',
    :'webhook_status_code' => :'Integer',
    :'webhook_attempts' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 277

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      rule_id == o.rule_id &&
      rule_tag == o.rule_tag &&
      tweet_id == o.tweet_id &&
      author_username == o.author_username &&
      tweet_text_preview == o.tweet_text_preview &&
      tweet_url == o.tweet_url &&
      tweet_published_at == o.tweet_published_at &&
      detected_at == o.detected_at &&
      latency_ms == o.latency_ms &&
      latency_badge == o.latency_badge &&
      delivery_status == o.delivery_status &&
      webhook_status_code == o.webhook_status_code &&
      webhook_attempts == o.webhook_attempts
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 406

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 304

def hash
  [id, rule_id, rule_tag, tweet_id, author_username, tweet_text_preview, tweet_url, tweet_published_at, detected_at, latency_ms, latency_badge, delivery_status, webhook_status_code, webhook_attempts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 202

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @rule_id.nil?
    invalid_properties.push('invalid value for "rule_id", rule_id cannot be nil.')
  end

  if @rule_tag.nil?
    invalid_properties.push('invalid value for "rule_tag", rule_tag cannot be nil.')
  end

  if @tweet_id.nil?
    invalid_properties.push('invalid value for "tweet_id", tweet_id cannot be nil.')
  end

  if @author_username.nil?
    invalid_properties.push('invalid value for "author_username", author_username cannot be nil.')
  end

  if @tweet_url.nil?
    invalid_properties.push('invalid value for "tweet_url", tweet_url cannot be nil.')
  end

  if @tweet_published_at.nil?
    invalid_properties.push('invalid value for "tweet_published_at", tweet_published_at cannot be nil.')
  end

  if @detected_at.nil?
    invalid_properties.push('invalid value for "detected_at", detected_at cannot be nil.')
  end

  if @latency_ms.nil?
    invalid_properties.push('invalid value for "latency_ms", latency_ms cannot be nil.')
  end

  if @latency_badge.nil?
    invalid_properties.push('invalid value for "latency_badge", latency_badge cannot be nil.')
  end

  if @delivery_status.nil?
    invalid_properties.push('invalid value for "delivery_status", delivery_status cannot be nil.')
  end

  if @webhook_attempts.nil?
    invalid_properties.push('invalid value for "webhook_attempts", webhook_attempts cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 382

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 388

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



376
377
378
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 376

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/scrapebadger/models/filter_rule_delivery_log_response.rb', line 258

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @rule_id.nil?
  return false if @rule_tag.nil?
  return false if @tweet_id.nil?
  return false if @author_username.nil?
  return false if @tweet_url.nil?
  return false if @tweet_published_at.nil?
  return false if @detected_at.nil?
  return false if @latency_ms.nil?
  return false if @latency_badge.nil?
  return false if @delivery_status.nil?
  return false if @webhook_attempts.nil?
  true
end