Class: ScrapeBadger::LinkedInApi

Inherits:
Object
  • Object
show all
Defined in:
lib/scrapebadger/api/linked_in_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ LinkedInApi

Returns a new instance of LinkedInApi.



19
20
21
# File 'lib/scrapebadger/api/linked_in_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/scrapebadger/api/linked_in_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#linkedin_get_a_company_s_job_postings(company_id, opts = {}) ⇒ Object

Get a company's job postings Public job postings for a company (numeric company id from the company endpoint).

Parameters:

  • company_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :start (Integer)

    Pagination offset (0, 25, 50, ...) (default to 0)

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


29
30
31
32
# File 'lib/scrapebadger/api/linked_in_api.rb', line 29

def linkedin_get_a_company_s_job_postings(company_id, opts = {})
  data, _status_code, _headers = linkedin_get_a_company_s_job_postings_with_http_info(company_id, opts)
  data
end

#linkedin_get_a_company_s_job_postings_with_http_info(company_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get a company's job postings Public job postings for a company (numeric company id from the company endpoint).

Parameters:

  • company_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :start (Integer)

    Pagination offset (0, 25, 50, ...) (default to 0)

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/scrapebadger/api/linked_in_api.rb', line 41

def linkedin_get_a_company_s_job_postings_with_http_info(company_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_a_company_s_job_postings ...'
  end
  # verify the required parameter 'company_id' is set
  if @api_client.config.client_side_validation && company_id.nil?
    fail ArgumentError, "Missing the required parameter 'company_id' when calling LinkedInApi.linkedin_get_a_company_s_job_postings"
  end
  if @api_client.config.client_side_validation && !opts[:'start'].nil? && opts[:'start'] < 0
    fail ArgumentError, 'invalid value for "opts[:"start"]" when calling LinkedInApi.linkedin_get_a_company_s_job_postings, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/v1/linkedin/companies/{company_id}/jobs'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'start'] = opts[:'start'] if !opts[:'start'].nil?
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_a_company_s_job_postings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_a_company_s_job_postings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_get_a_course(course_slug, opts = {}) ⇒ Object

Get a course A public LinkedIn Learning course — provider, workload, instructors, rating.

Parameters:

  • course_slug (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


101
102
103
104
# File 'lib/scrapebadger/api/linked_in_api.rb', line 101

def linkedin_get_a_course(course_slug, opts = {})
  data, _status_code, _headers = linkedin_get_a_course_with_http_info(course_slug, opts)
  data
end

#linkedin_get_a_course_with_http_info(course_slug, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get a course A public LinkedIn Learning course — provider, workload, instructors, rating.

Parameters:

  • course_slug (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/scrapebadger/api/linked_in_api.rb', line 112

def linkedin_get_a_course_with_http_info(course_slug, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_a_course ...'
  end
  # verify the required parameter 'course_slug' is set
  if @api_client.config.client_side_validation && course_slug.nil?
    fail ArgumentError, "Missing the required parameter 'course_slug' when calling LinkedInApi.linkedin_get_a_course"
  end
  # resource path
  local_var_path = '/v1/linkedin/learning/{course_slug}'.sub('{' + 'course_slug' + '}', CGI.escape(course_slug.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_a_course",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_a_course\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_get_a_public_article(article_slug, opts = {}) ⇒ Object

Get a public article A public Pulse article — title, body, author, reactions (JSON-LD).

Parameters:

  • article_slug (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


167
168
169
170
# File 'lib/scrapebadger/api/linked_in_api.rb', line 167

def linkedin_get_a_public_article(article_slug, opts = {})
  data, _status_code, _headers = linkedin_get_a_public_article_with_http_info(article_slug, opts)
  data
end

#linkedin_get_a_public_article_with_http_info(article_slug, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get a public article A public Pulse article — title, body, author, reactions (JSON-LD).

Parameters:

  • article_slug (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/scrapebadger/api/linked_in_api.rb', line 178

def linkedin_get_a_public_article_with_http_info(article_slug, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_a_public_article ...'
  end
  # verify the required parameter 'article_slug' is set
  if @api_client.config.client_side_validation && article_slug.nil?
    fail ArgumentError, "Missing the required parameter 'article_slug' when calling LinkedInApi.linkedin_get_a_public_article"
  end
  # resource path
  local_var_path = '/v1/linkedin/articles/{article_slug}'.sub('{' + 'article_slug' + '}', CGI.escape(article_slug.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_a_public_article",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_a_public_article\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_get_a_public_post(post_slug, opts = {}) ⇒ Object

Get a public post A public activity share — text, author, reactions, comments (JSON-LD).

Parameters:

  • post_slug (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


233
234
235
236
# File 'lib/scrapebadger/api/linked_in_api.rb', line 233

def linkedin_get_a_public_post(post_slug, opts = {})
  data, _status_code, _headers = linkedin_get_a_public_post_with_http_info(post_slug, opts)
  data
end

#linkedin_get_a_public_post_with_http_info(post_slug, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get a public post A public activity share — text, author, reactions, comments (JSON-LD).

Parameters:

  • post_slug (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/scrapebadger/api/linked_in_api.rb', line 244

def linkedin_get_a_public_post_with_http_info(post_slug, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_a_public_post ...'
  end
  # verify the required parameter 'post_slug' is set
  if @api_client.config.client_side_validation && post_slug.nil?
    fail ArgumentError, "Missing the required parameter 'post_slug' when calling LinkedInApi.linkedin_get_a_public_post"
  end
  # resource path
  local_var_path = '/v1/linkedin/posts/{post_slug}'.sub('{' + 'post_slug' + '}', CGI.escape(post_slug.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_a_public_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_a_public_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_get_company(universal_name, opts = {}) ⇒ Object

Get company Public company page — industry, size, HQ, followers, specialties (JSON-LD + SSR).

Parameters:

  • universal_name (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


299
300
301
302
# File 'lib/scrapebadger/api/linked_in_api.rb', line 299

def linkedin_get_company(universal_name, opts = {})
  data, _status_code, _headers = linkedin_get_company_with_http_info(universal_name, opts)
  data
end

#linkedin_get_company_with_http_info(universal_name, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get company Public company page — industry, size, HQ, followers, specialties (JSON-LD + SSR).

Parameters:

  • universal_name (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/scrapebadger/api/linked_in_api.rb', line 310

def linkedin_get_company_with_http_info(universal_name, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_company ...'
  end
  # verify the required parameter 'universal_name' is set
  if @api_client.config.client_side_validation && universal_name.nil?
    fail ArgumentError, "Missing the required parameter 'universal_name' when calling LinkedInApi.linkedin_get_company"
  end
  # resource path
  local_var_path = '/v1/linkedin/companies/{universal_name}'.sub('{' + 'universal_name' + '}', CGI.escape(universal_name.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_company",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_company\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_get_job_detail(job_id, opts = {}) ⇒ Object

Get job detail Full detail for one job posting (guest API, no login).

Parameters:

  • job_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


365
366
367
368
# File 'lib/scrapebadger/api/linked_in_api.rb', line 365

def linkedin_get_job_detail(job_id, opts = {})
  data, _status_code, _headers = linkedin_get_job_detail_with_http_info(job_id, opts)
  data
end

#linkedin_get_job_detail_with_http_info(job_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get job detail Full detail for one job posting (guest API, no login).

Parameters:

  • job_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/scrapebadger/api/linked_in_api.rb', line 376

def linkedin_get_job_detail_with_http_info(job_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_job_detail ...'
  end
  # verify the required parameter 'job_id' is set
  if @api_client.config.client_side_validation && job_id.nil?
    fail ArgumentError, "Missing the required parameter 'job_id' when calling LinkedInApi.linkedin_get_job_detail"
  end
  # resource path
  local_var_path = '/v1/linkedin/jobs/{job_id}'.sub('{' + 'job_id' + '}', CGI.escape(job_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_job_detail",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_job_detail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_get_public_profile(public_id, opts = {}) ⇒ Object

Get public profile Public profile by vanity id (the /in/{public_id} slug) — name, headline, location, about, experience, education (public JSON-LD + SSR subset).

Parameters:

  • public_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


431
432
433
434
# File 'lib/scrapebadger/api/linked_in_api.rb', line 431

def linkedin_get_public_profile(public_id, opts = {})
  data, _status_code, _headers = linkedin_get_public_profile_with_http_info(public_id, opts)
  data
end

#linkedin_get_public_profile_with_http_info(public_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get public profile Public profile by vanity id (the ``/in/public_id`` slug) — name, headline, location, about, experience, education (public JSON-LD + SSR subset).

Parameters:

  • public_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/scrapebadger/api/linked_in_api.rb', line 442

def linkedin_get_public_profile_with_http_info(public_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_public_profile ...'
  end
  # verify the required parameter 'public_id' is set
  if @api_client.config.client_side_validation && public_id.nil?
    fail ArgumentError, "Missing the required parameter 'public_id' when calling LinkedInApi.linkedin_get_public_profile"
  end
  # resource path
  local_var_path = '/v1/linkedin/profiles/{public_id}'.sub('{' + 'public_id' + '}', CGI.escape(public_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_public_profile",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_public_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_get_school(universal_name, opts = {}) ⇒ Object

Get school Public school page — name, description, website, follower/alumni counts.

Parameters:

  • universal_name (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


497
498
499
500
# File 'lib/scrapebadger/api/linked_in_api.rb', line 497

def linkedin_get_school(universal_name, opts = {})
  data, _status_code, _headers = linkedin_get_school_with_http_info(universal_name, opts)
  data
end

#linkedin_get_school_with_http_info(universal_name, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get school Public school page — name, description, website, follower/alumni counts.

Parameters:

  • universal_name (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/scrapebadger/api/linked_in_api.rb', line 508

def linkedin_get_school_with_http_info(universal_name, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_get_school ...'
  end
  # verify the required parameter 'universal_name' is set
  if @api_client.config.client_side_validation && universal_name.nil?
    fail ArgumentError, "Missing the required parameter 'universal_name' when calling LinkedInApi.linkedin_get_school"
  end
  # resource path
  local_var_path = '/v1/linkedin/schools/{universal_name}'.sub('{' + 'universal_name' + '}', CGI.escape(universal_name.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_get_school",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_get_school\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_linkedin_scraper_health_check(opts = {}) ⇒ Object

LinkedIn scraper health check Check health of the LinkedIn scraper service (accepts HEAD).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


561
562
563
564
# File 'lib/scrapebadger/api/linked_in_api.rb', line 561

def linkedin_linkedin_scraper_health_check(opts = {})
  data, _status_code, _headers = linkedin_linkedin_scraper_health_check_with_http_info(opts)
  data
end

#linkedin_linkedin_scraper_health_check_head(opts = {}) ⇒ Object

LinkedIn scraper health check Check health of the LinkedIn scraper service (accepts HEAD).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


618
619
620
621
# File 'lib/scrapebadger/api/linked_in_api.rb', line 618

def linkedin_linkedin_scraper_health_check_head(opts = {})
  data, _status_code, _headers = linkedin_linkedin_scraper_health_check_head_with_http_info(opts)
  data
end

#linkedin_linkedin_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

LinkedIn scraper health check Check health of the LinkedIn scraper service (accepts HEAD).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'lib/scrapebadger/api/linked_in_api.rb', line 627

def linkedin_linkedin_scraper_health_check_head_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_linkedin_scraper_health_check_head ...'
  end
  # resource path
  local_var_path = '/v1/linkedin/health'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_linkedin_scraper_health_check_head",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_linkedin_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_linkedin_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

LinkedIn scraper health check Check health of the LinkedIn scraper service (accepts HEAD).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/scrapebadger/api/linked_in_api.rb', line 570

def linkedin_linkedin_scraper_health_check_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_linkedin_scraper_health_check ...'
  end
  # resource path
  local_var_path = '/v1/linkedin/health'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_linkedin_scraper_health_check",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_linkedin_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_search_linkedin_jobs(opts = {}) ⇒ Object

Search LinkedIn jobs Search public LinkedIn job postings (guest API, no login).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :keywords (String)

    Job title / keywords

  • :location (String)

    Location text, e.g. 'New York'

  • :geo_id (String)

    LinkedIn numeric geo id (overrides location)

  • :company_id (String)

    Restrict to a company (numeric id)

  • :date_posted (String)

    past_24h | past_week | past_month | any

  • :experience (String)

    internship|entry|associate|mid_senior|director|executive (comma-separated)

  • :job_type (String)

    full_time|part_time|contract|temporary|internship|volunteer|other

  • :workplace (String)

    onsite|remote|hybrid (comma-separated)

  • :sort (String)

    relevant | recent

  • :start (Integer)

    Pagination offset (0, 25, 50, ...) (default to 0)

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Object)


686
687
688
689
# File 'lib/scrapebadger/api/linked_in_api.rb', line 686

def linkedin_search_linkedin_jobs(opts = {})
  data, _status_code, _headers = linkedin_search_linkedin_jobs_with_http_info(opts)
  data
end

#linkedin_search_linkedin_jobs_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

Search LinkedIn jobs Search public LinkedIn job postings (guest API, no login).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :keywords (String)

    Job title / keywords

  • :location (String)

    Location text, e.g. 'New York'

  • :geo_id (String)

    LinkedIn numeric geo id (overrides location)

  • :company_id (String)

    Restrict to a company (numeric id)

  • :date_posted (String)

    past_24h | past_week | past_month | any

  • :experience (String)

    internship|entry|associate|mid_senior|director|executive (comma-separated)

  • :job_type (String)

    full_time|part_time|contract|temporary|internship|volunteer|other

  • :workplace (String)

    onsite|remote|hybrid (comma-separated)

  • :sort (String)

    relevant | recent

  • :start (Integer)

    Pagination offset (0, 25, 50, ...) (default to 0)

  • :country (String)

    Residential proxy country (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/scrapebadger/api/linked_in_api.rb', line 706

def linkedin_search_linkedin_jobs_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_search_linkedin_jobs ...'
  end
  if @api_client.config.client_side_validation && !opts[:'start'].nil? && opts[:'start'] < 0
    fail ArgumentError, 'invalid value for "opts[:"start"]" when calling LinkedInApi.linkedin_search_linkedin_jobs, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/v1/linkedin/jobs/search'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'keywords'] = opts[:'keywords'] if !opts[:'keywords'].nil?
  query_params[:'location'] = opts[:'location'] if !opts[:'location'].nil?
  query_params[:'geo_id'] = opts[:'geo_id'] if !opts[:'geo_id'].nil?
  query_params[:'company_id'] = opts[:'company_id'] if !opts[:'company_id'].nil?
  query_params[:'date_posted'] = opts[:'date_posted'] if !opts[:'date_posted'].nil?
  query_params[:'experience'] = opts[:'experience'] if !opts[:'experience'].nil?
  query_params[:'job_type'] = opts[:'job_type'] if !opts[:'job_type'].nil?
  query_params[:'workplace'] = opts[:'workplace'] if !opts[:'workplace'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'start'] = opts[:'start'] if !opts[:'start'].nil?
  query_params[:'country'] = opts[:'country'] if !opts[:'country'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_search_linkedin_jobs",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_search_linkedin_jobs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#linkedin_suggest_location_geo_ids(query, opts = {}) ⇒ Object

Suggest location geo ids Resolve a name to LinkedIn ids (job-search geo_id / company_id helper).

Parameters:

  • query (String)

    Location text, e.g. 'London'

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    geo | company (default to 'geo')

Returns:

  • (Object)


771
772
773
774
# File 'lib/scrapebadger/api/linked_in_api.rb', line 771

def linkedin_suggest_location_geo_ids(query, opts = {})
  data, _status_code, _headers = linkedin_suggest_location_geo_ids_with_http_info(query, opts)
  data
end

#linkedin_suggest_location_geo_ids_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Suggest location geo ids Resolve a name to LinkedIn ids (job-search ``geo_id`` / ``company_id`` helper).

Parameters:

  • query (String)

    Location text, e.g. 'London'

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    geo | company (default to 'geo')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
# File 'lib/scrapebadger/api/linked_in_api.rb', line 782

def linkedin_suggest_location_geo_ids_with_http_info(query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LinkedInApi.linkedin_suggest_location_geo_ids ...'
  end
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling LinkedInApi.linkedin_suggest_location_geo_ids"
  end
  # resource path
  local_var_path = '/v1/linkedin/geo/suggest'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query
  query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LinkedInApi.linkedin_suggest_location_geo_ids",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LinkedInApi#linkedin_suggest_location_geo_ids\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end