Class: ScrapeBadger::LoopNetApi

Inherits:
Object
  • Object
show all
Defined in:
lib/scrapebadger/api/loop_net_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ LoopNetApi

Returns a new instance of LoopNetApi.



19
20
21
# File 'lib/scrapebadger/api/loop_net_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/scrapebadger/api/loop_net_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#loopnet_get_broker_profile(slug, broker_id, opts = {}) ⇒ Object

Get broker profile Get a LoopNet broker profile + their listings by slug + id.

Parameters:

  • slug (String)
  • broker_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :market (String)

    us|ca|uk|fr|es (default to 'us')

Returns:

  • (Object)


29
30
31
32
# File 'lib/scrapebadger/api/loop_net_api.rb', line 29

def loopnet_get_broker_profile(slug, broker_id, opts = {})
  data, _status_code, _headers = loopnet_get_broker_profile_with_http_info(slug, broker_id, opts)
  data
end

#loopnet_get_broker_profile_with_http_info(slug, broker_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get broker profile Get a LoopNet broker profile + their listings by slug + id.

Parameters:

  • slug (String)
  • broker_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :market (String)

    us|ca|uk|fr|es (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/scrapebadger/api/loop_net_api.rb', line 41

def loopnet_get_broker_profile_with_http_info(slug, broker_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LoopNetApi.loopnet_get_broker_profile ...'
  end
  # verify the required parameter 'slug' is set
  if @api_client.config.client_side_validation && slug.nil?
    fail ArgumentError, "Missing the required parameter 'slug' when calling LoopNetApi.loopnet_get_broker_profile"
  end
  # verify the required parameter 'broker_id' is set
  if @api_client.config.client_side_validation && broker_id.nil?
    fail ArgumentError, "Missing the required parameter 'broker_id' when calling LoopNetApi.loopnet_get_broker_profile"
  end
  # resource path
  local_var_path = '/v1/loopnet/brokers/{slug}/{broker_id}'.sub('{' + 'slug' + '}', CGI.escape(slug.to_s)).sub('{' + 'broker_id' + '}', CGI.escape(broker_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LoopNetApi.loopnet_get_broker_profile",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LoopNetApi#loopnet_get_broker_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#loopnet_get_listing_detail(listing_id, opts = {}) ⇒ Object

Get listing detail Get a single LoopNet listing's full detail by its numeric id.

Parameters:

  • listing_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :market (String)

    us|ca|uk|fr|es (default to 'us')

Returns:

  • (Object)


100
101
102
103
# File 'lib/scrapebadger/api/loop_net_api.rb', line 100

def loopnet_get_listing_detail(listing_id, opts = {})
  data, _status_code, _headers = loopnet_get_listing_detail_with_http_info(listing_id, opts)
  data
end

#loopnet_get_listing_detail_with_http_info(listing_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get listing detail Get a single LoopNet listing's full detail by its numeric id.

Parameters:

  • listing_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :market (String)

    us|ca|uk|fr|es (default to 'us')

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/scrapebadger/api/loop_net_api.rb', line 111

def loopnet_get_listing_detail_with_http_info(listing_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LoopNetApi.loopnet_get_listing_detail ...'
  end
  # verify the required parameter 'listing_id' is set
  if @api_client.config.client_side_validation && listing_id.nil?
    fail ArgumentError, "Missing the required parameter 'listing_id' when calling LoopNetApi.loopnet_get_listing_detail"
  end
  # resource path
  local_var_path = '/v1/loopnet/listings/{listing_id}'.sub('{' + 'listing_id' + '}', CGI.escape(listing_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LoopNetApi.loopnet_get_listing_detail",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LoopNetApi#loopnet_get_listing_detail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#loopnet_list_coverage_markets(opts = {}) ⇒ Object

List coverage markets List LoopNet coverage markets (US, CA, UK, FR, ES).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


164
165
166
167
# File 'lib/scrapebadger/api/loop_net_api.rb', line 164

def loopnet_list_coverage_markets(opts = {})
  data, _status_code, _headers = loopnet_list_coverage_markets_with_http_info(opts)
  data
end

#loopnet_list_coverage_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

List coverage markets List LoopNet coverage markets (US, CA, UK, FR, ES).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/scrapebadger/api/loop_net_api.rb', line 173

def loopnet_list_coverage_markets_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LoopNetApi.loopnet_list_coverage_markets ...'
  end
  # resource path
  local_var_path = '/v1/loopnet/markets'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LoopNetApi.loopnet_list_coverage_markets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LoopNetApi#loopnet_list_coverage_markets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#loopnet_list_property_types(opts = {}) ⇒ Object

List property types List LoopNet property-type facets accepted by /search.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


221
222
223
224
# File 'lib/scrapebadger/api/loop_net_api.rb', line 221

def loopnet_list_property_types(opts = {})
  data, _status_code, _headers = loopnet_list_property_types_with_http_info(opts)
  data
end

#loopnet_list_property_types_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

List property types List LoopNet property-type facets accepted by /search.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/scrapebadger/api/loop_net_api.rb', line 230

def loopnet_list_property_types_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LoopNetApi.loopnet_list_property_types ...'
  end
  # resource path
  local_var_path = '/v1/loopnet/property-types'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LoopNetApi.loopnet_list_property_types",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LoopNetApi#loopnet_list_property_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#loopnet_loopnet_scraper_health_check(opts = {}) ⇒ Object

LoopNet scraper health check Check health of the LoopNet scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


278
279
280
281
# File 'lib/scrapebadger/api/loop_net_api.rb', line 278

def loopnet_loopnet_scraper_health_check(opts = {})
  data, _status_code, _headers = loopnet_loopnet_scraper_health_check_with_http_info(opts)
  data
end

#loopnet_loopnet_scraper_health_check_head(opts = {}) ⇒ Object

LoopNet scraper health check Check health of the LoopNet scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


335
336
337
338
# File 'lib/scrapebadger/api/loop_net_api.rb', line 335

def loopnet_loopnet_scraper_health_check_head(opts = {})
  data, _status_code, _headers = loopnet_loopnet_scraper_health_check_head_with_http_info(opts)
  data
end

#loopnet_loopnet_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

LoopNet scraper health check Check health of the LoopNet scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/scrapebadger/api/loop_net_api.rb', line 344

def loopnet_loopnet_scraper_health_check_head_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LoopNetApi.loopnet_loopnet_scraper_health_check_head ...'
  end
  # resource path
  local_var_path = '/v1/loopnet/health'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LoopNetApi.loopnet_loopnet_scraper_health_check_head",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LoopNetApi#loopnet_loopnet_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#loopnet_loopnet_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

LoopNet scraper health check Check health of the LoopNet scraper service (accepts HEAD for UptimeRobot).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/scrapebadger/api/loop_net_api.rb', line 287

def loopnet_loopnet_scraper_health_check_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LoopNetApi.loopnet_loopnet_scraper_health_check ...'
  end
  # resource path
  local_var_path = '/v1/loopnet/health'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LoopNetApi.loopnet_loopnet_scraper_health_check",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LoopNetApi#loopnet_loopnet_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#loopnet_search_commercial_real_estate(location, opts = {}) ⇒ Object

Search commercial real estate Search LoopNet for-lease / for-sale / auction listings across all markets.

Parameters:

  • location (String)

    City/state, ZIP, state code, or 'usa'

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :market (String)

    us|ca|uk|fr|es (default to 'us')

  • :listing_type (String)

    for-lease|for-sale|auctions (default to 'for-lease')

  • :property_type (String)

    Slug from /property-types

  • :page (Integer) — default: default to 1
  • :min_price (Integer)
  • :max_price (Integer)
  • :price_type (String)

    unit | sf | acre

  • :min_size (Integer)
  • :max_size (Integer)

Returns:

  • (Object)


402
403
404
405
# File 'lib/scrapebadger/api/loop_net_api.rb', line 402

def loopnet_search_commercial_real_estate(location, opts = {})
  data, _status_code, _headers = loopnet_search_commercial_real_estate_with_http_info(location, opts)
  data
end

#loopnet_search_commercial_real_estate_with_http_info(location, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Search commercial real estate Search LoopNet for-lease / for-sale / auction listings across all markets.

Parameters:

  • location (String)

    City/state, ZIP, state code, or 'usa'

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :market (String)

    us|ca|uk|fr|es (default to 'us')

  • :listing_type (String)

    for-lease|for-sale|auctions (default to 'for-lease')

  • :property_type (String)

    Slug from /property-types

  • :page (Integer) — default: default to 1
  • :min_price (Integer)
  • :max_price (Integer)
  • :price_type (String)

    unit | sf | acre

  • :min_size (Integer)
  • :max_size (Integer)

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/scrapebadger/api/loop_net_api.rb', line 421

def loopnet_search_commercial_real_estate_with_http_info(location, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LoopNetApi.loopnet_search_commercial_real_estate ...'
  end
  # verify the required parameter 'location' is set
  if @api_client.config.client_side_validation && location.nil?
    fail ArgumentError, "Missing the required parameter 'location' when calling LoopNetApi.loopnet_search_commercial_real_estate"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 20
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling LoopNetApi.loopnet_search_commercial_real_estate, must be smaller than or equal to 20.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling LoopNetApi.loopnet_search_commercial_real_estate, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 0
    fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling LoopNetApi.loopnet_search_commercial_real_estate, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 0
    fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling LoopNetApi.loopnet_search_commercial_real_estate, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'min_size'].nil? && opts[:'min_size'] < 0
    fail ArgumentError, 'invalid value for "opts[:"min_size"]" when calling LoopNetApi.loopnet_search_commercial_real_estate, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'max_size'].nil? && opts[:'max_size'] < 0
    fail ArgumentError, 'invalid value for "opts[:"max_size"]" when calling LoopNetApi.loopnet_search_commercial_real_estate, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/v1/loopnet/search'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'location'] = location
  query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil?
  query_params[:'listing_type'] = opts[:'listing_type'] if !opts[:'listing_type'].nil?
  query_params[:'property_type'] = opts[:'property_type'] if !opts[:'property_type'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil?
  query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil?
  query_params[:'price_type'] = opts[:'price_type'] if !opts[:'price_type'].nil?
  query_params[:'min_size'] = opts[:'min_size'] if !opts[:'min_size'].nil?
  query_params[:'max_size'] = opts[:'max_size'] if !opts[:'max_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"LoopNetApi.loopnet_search_commercial_real_estate",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LoopNetApi#loopnet_search_commercial_real_estate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end