Class: ScrapeBadger::SubscriptionInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/scrapebadger/models/subscription_info.rb

Overview

Active subscription details (null when PAYG-only).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/scrapebadger/models/subscription_info.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ScrapeBadger::SubscriptionInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ScrapeBadger::SubscriptionInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'plan_code')
    self.plan_code = attributes[:'plan_code']
  else
    self.plan_code = nil
  end

  if attributes.key?(:'plan_title')
    self.plan_title = attributes[:'plan_title']
  else
    self.plan_title = nil
  end

  if attributes.key?(:'billing_cadence')
    self.billing_cadence = attributes[:'billing_cadence']
  else
    self.billing_cadence = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'current_period_start')
    self.current_period_start = attributes[:'current_period_start']
  end

  if attributes.key?(:'current_period_end')
    self.current_period_end = attributes[:'current_period_end']
  end

  if attributes.key?(:'cancel_at_period_end')
    self.cancel_at_period_end = attributes[:'cancel_at_period_end']
  else
    self.cancel_at_period_end = false
  end

  if attributes.key?(:'cancel_effective_at')
    self.cancel_effective_at = attributes[:'cancel_effective_at']
  end

  if attributes.key?(:'monthly_credits')
    self.monthly_credits = attributes[:'monthly_credits']
  else
    self.monthly_credits = 0
  end

  if attributes.key?(:'pending_plan_code')
    self.pending_plan_code = attributes[:'pending_plan_code']
  end

  if attributes.key?(:'pending_plan_title')
    self.pending_plan_title = attributes[:'pending_plan_title']
  end

  if attributes.key?(:'pending_change_effective_at')
    self.pending_change_effective_at = attributes[:'pending_change_effective_at']
  end
end

Instance Attribute Details

#billing_cadenceObject

Returns the value of attribute billing_cadence.



23
24
25
# File 'lib/scrapebadger/models/subscription_info.rb', line 23

def billing_cadence
  @billing_cadence
end

#cancel_at_period_endObject

Returns the value of attribute cancel_at_period_end.



31
32
33
# File 'lib/scrapebadger/models/subscription_info.rb', line 31

def cancel_at_period_end
  @cancel_at_period_end
end

#cancel_effective_atObject

Returns the value of attribute cancel_effective_at.



33
34
35
# File 'lib/scrapebadger/models/subscription_info.rb', line 33

def cancel_effective_at
  @cancel_effective_at
end

#current_period_endObject

Returns the value of attribute current_period_end.



29
30
31
# File 'lib/scrapebadger/models/subscription_info.rb', line 29

def current_period_end
  @current_period_end
end

#current_period_startObject

Returns the value of attribute current_period_start.



27
28
29
# File 'lib/scrapebadger/models/subscription_info.rb', line 27

def current_period_start
  @current_period_start
end

#monthly_creditsObject

Returns the value of attribute monthly_credits.



35
36
37
# File 'lib/scrapebadger/models/subscription_info.rb', line 35

def monthly_credits
  @monthly_credits
end

#pending_change_effective_atObject

Returns the value of attribute pending_change_effective_at.



41
42
43
# File 'lib/scrapebadger/models/subscription_info.rb', line 41

def pending_change_effective_at
  @pending_change_effective_at
end

#pending_plan_codeObject

Returns the value of attribute pending_plan_code.



37
38
39
# File 'lib/scrapebadger/models/subscription_info.rb', line 37

def pending_plan_code
  @pending_plan_code
end

#pending_plan_titleObject

Returns the value of attribute pending_plan_title.



39
40
41
# File 'lib/scrapebadger/models/subscription_info.rb', line 39

def pending_plan_title
  @pending_plan_title
end

#plan_codeObject

Returns the value of attribute plan_code.



19
20
21
# File 'lib/scrapebadger/models/subscription_info.rb', line 19

def plan_code
  @plan_code
end

#plan_titleObject

Returns the value of attribute plan_title.



21
22
23
# File 'lib/scrapebadger/models/subscription_info.rb', line 21

def plan_title
  @plan_title
end

#statusObject

Returns the value of attribute status.



25
26
27
# File 'lib/scrapebadger/models/subscription_info.rb', line 25

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/scrapebadger/models/subscription_info.rb', line 265

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ScrapeBadger.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/scrapebadger/models/subscription_info.rb', line 62

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/scrapebadger/models/subscription_info.rb', line 44

def self.attribute_map
  {
    :'plan_code' => :'plan_code',
    :'plan_title' => :'plan_title',
    :'billing_cadence' => :'billing_cadence',
    :'status' => :'status',
    :'current_period_start' => :'current_period_start',
    :'current_period_end' => :'current_period_end',
    :'cancel_at_period_end' => :'cancel_at_period_end',
    :'cancel_effective_at' => :'cancel_effective_at',
    :'monthly_credits' => :'monthly_credits',
    :'pending_plan_code' => :'pending_plan_code',
    :'pending_plan_title' => :'pending_plan_title',
    :'pending_change_effective_at' => :'pending_change_effective_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/scrapebadger/models/subscription_info.rb', line 241

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
90
91
92
93
94
# File 'lib/scrapebadger/models/subscription_info.rb', line 85

def self.openapi_nullable
  Set.new([
    :'current_period_start',
    :'current_period_end',
    :'cancel_effective_at',
    :'pending_plan_code',
    :'pending_plan_title',
    :'pending_change_effective_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/scrapebadger/models/subscription_info.rb', line 67

def self.openapi_types
  {
    :'plan_code' => :'String',
    :'plan_title' => :'String',
    :'billing_cadence' => :'String',
    :'status' => :'String',
    :'current_period_start' => :'Time',
    :'current_period_end' => :'Time',
    :'cancel_at_period_end' => :'Boolean',
    :'cancel_effective_at' => :'Time',
    :'monthly_credits' => :'Integer',
    :'pending_plan_code' => :'String',
    :'pending_plan_title' => :'String',
    :'pending_change_effective_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/scrapebadger/models/subscription_info.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      plan_code == o.plan_code &&
      plan_title == o.plan_title &&
      billing_cadence == o.billing_cadence &&
      status == o.status &&
      current_period_start == o.current_period_start &&
      current_period_end == o.current_period_end &&
      cancel_at_period_end == o.cancel_at_period_end &&
      cancel_effective_at == o.cancel_effective_at &&
      monthly_credits == o.monthly_credits &&
      pending_plan_code == o.pending_plan_code &&
      pending_plan_title == o.pending_plan_title &&
      pending_change_effective_at == o.pending_change_effective_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/scrapebadger/models/subscription_info.rb', line 336

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/scrapebadger/models/subscription_info.rb', line 228

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



234
235
236
# File 'lib/scrapebadger/models/subscription_info.rb', line 234

def hash
  [plan_code, plan_title, billing_cadence, status, current_period_start, current_period_end, cancel_at_period_end, cancel_effective_at, monthly_credits, pending_plan_code, pending_plan_title, pending_change_effective_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/scrapebadger/models/subscription_info.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @plan_code.nil?
    invalid_properties.push('invalid value for "plan_code", plan_code cannot be nil.')
  end

  if @plan_title.nil?
    invalid_properties.push('invalid value for "plan_title", plan_title cannot be nil.')
  end

  if @billing_cadence.nil?
    invalid_properties.push('invalid value for "billing_cadence", billing_cadence cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
# File 'lib/scrapebadger/models/subscription_info.rb', line 312

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/scrapebadger/models/subscription_info.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



306
307
308
# File 'lib/scrapebadger/models/subscription_info.rb', line 306

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



198
199
200
201
202
203
204
205
# File 'lib/scrapebadger/models/subscription_info.rb', line 198

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @plan_code.nil?
  return false if @plan_title.nil?
  return false if @billing_cadence.nil?
  return false if @status.nil?
  true
end