Class: ScrapeBadger::ApartmentsApi
- Inherits:
-
Object
- Object
- ScrapeBadger::ApartmentsApi
- Defined in:
- lib/scrapebadger/api/apartments_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#apartments_apartments_scraper_health_check(opts = {}) ⇒ Object
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
-
#apartments_apartments_scraper_health_check_head(opts = {}) ⇒ Object
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
-
#apartments_apartments_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
-
#apartments_apartments_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
-
#apartments_get_property_detail_by_slug_id(slug, property_id, opts = {}) ⇒ Object
Get property detail by slug + id Get a property by its SEO slug and 7-character listing id.
-
#apartments_get_property_detail_by_slug_id_with_http_info(slug, property_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail by slug + id Get a property by its SEO slug and 7-character listing id.
-
#apartments_get_property_detail_by_url(url, opts = {}) ⇒ Object
Get property detail by URL Get an apartments.com property with full per-unit pricing and availability.
-
#apartments_get_property_detail_by_url_with_http_info(url, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail by URL Get an apartments.com property with full per-unit pricing and availability.
-
#apartments_search_rental_listings(location, opts = {}) ⇒ Object
Search rental listings Search apartments.com for rental properties.
-
#apartments_search_rental_listings_with_http_info(location, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search rental listings Search apartments.com for rental properties.
-
#initialize(api_client = ApiClient.default) ⇒ ApartmentsApi
constructor
A new instance of ApartmentsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ApartmentsApi
Returns a new instance of ApartmentsApi.
19 20 21 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#apartments_apartments_scraper_health_check(opts = {}) ⇒ Object
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
26 27 28 29 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 26 def apartments_apartments_scraper_health_check(opts = {}) data, _status_code, _headers = apartments_apartments_scraper_health_check_with_http_info(opts) data end |
#apartments_apartments_scraper_health_check_head(opts = {}) ⇒ Object
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
83 84 85 86 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 83 def apartments_apartments_scraper_health_check_head(opts = {}) data, _status_code, _headers = apartments_apartments_scraper_health_check_head_with_http_info(opts) data end |
#apartments_apartments_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 92 def apartments_apartments_scraper_health_check_head_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApartmentsApi.apartments_apartments_scraper_health_check_head ...' end # resource path local_var_path = '/v1/apartments/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ApartmentsApi.apartments_apartments_scraper_health_check_head", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApartmentsApi#apartments_apartments_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#apartments_apartments_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Apartments scraper health check Check health of the Apartments scraper service (accepts HEAD for UptimeRobot).
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 35 def apartments_apartments_scraper_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApartmentsApi.apartments_apartments_scraper_health_check ...' end # resource path local_var_path = '/v1/apartments/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ApartmentsApi.apartments_apartments_scraper_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApartmentsApi#apartments_apartments_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#apartments_get_property_detail_by_slug_id(slug, property_id, opts = {}) ⇒ Object
Get property detail by slug + id Get a property by its SEO slug and 7-character listing id.
142 143 144 145 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 142 def apartments_get_property_detail_by_slug_id(slug, property_id, opts = {}) data, _status_code, _headers = apartments_get_property_detail_by_slug_id_with_http_info(slug, property_id, opts) data end |
#apartments_get_property_detail_by_slug_id_with_http_info(slug, property_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail by slug + id Get a property by its SEO slug and 7-character listing id.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 153 def apartments_get_property_detail_by_slug_id_with_http_info(slug, property_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApartmentsApi.apartments_get_property_detail_by_slug_id ...' end # verify the required parameter 'slug' is set if @api_client.config.client_side_validation && slug.nil? fail ArgumentError, "Missing the required parameter 'slug' when calling ApartmentsApi.apartments_get_property_detail_by_slug_id" end # verify the required parameter 'property_id' is set if @api_client.config.client_side_validation && property_id.nil? fail ArgumentError, "Missing the required parameter 'property_id' when calling ApartmentsApi.apartments_get_property_detail_by_slug_id" end # resource path local_var_path = '/v1/apartments/properties/{slug}/{property_id}'.sub('{' + 'slug' + '}', CGI.escape(slug.to_s)).sub('{' + 'property_id' + '}', CGI.escape(property_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ApartmentsApi.apartments_get_property_detail_by_slug_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApartmentsApi#apartments_get_property_detail_by_slug_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#apartments_get_property_detail_by_url(url, opts = {}) ⇒ Object
Get property detail by URL Get an apartments.com property with full per-unit pricing and availability.
210 211 212 213 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 210 def apartments_get_property_detail_by_url(url, opts = {}) data, _status_code, _headers = apartments_get_property_detail_by_url_with_http_info(url, opts) data end |
#apartments_get_property_detail_by_url_with_http_info(url, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail by URL Get an apartments.com property with full per-unit pricing and availability.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 220 def apartments_get_property_detail_by_url_with_http_info(url, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApartmentsApi.apartments_get_property_detail_by_url ...' end # verify the required parameter 'url' is set if @api_client.config.client_side_validation && url.nil? fail ArgumentError, "Missing the required parameter 'url' when calling ApartmentsApi.apartments_get_property_detail_by_url" end # resource path local_var_path = '/v1/apartments/property' # query parameters query_params = opts[:query_params] || {} query_params[:'url'] = url # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ApartmentsApi.apartments_get_property_detail_by_url", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApartmentsApi#apartments_get_property_detail_by_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#apartments_search_rental_listings(location, opts = {}) ⇒ Object
Search rental listings Search apartments.com for rental properties. 40 cards per page.
278 279 280 281 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 278 def apartments_search_rental_listings(location, opts = {}) data, _status_code, _headers = apartments_search_rental_listings_with_http_info(location, opts) data end |
#apartments_search_rental_listings_with_http_info(location, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search rental listings Search apartments.com for rental properties. 40 cards per page.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/scrapebadger/api/apartments_api.rb', line 292 def apartments_search_rental_listings_with_http_info(location, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApartmentsApi.apartments_search_rental_listings ...' end # verify the required parameter 'location' is set if @api_client.config.client_side_validation && location.nil? fail ArgumentError, "Missing the required parameter 'location' when calling ApartmentsApi.apartments_search_rental_listings" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 28 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ApartmentsApi.apartments_search_rental_listings, must be smaller than or equal to 28.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ApartmentsApi.apartments_search_rental_listings, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'beds'].nil? && opts[:'beds'] > 4 fail ArgumentError, 'invalid value for "opts[:"beds"]" when calling ApartmentsApi.apartments_search_rental_listings, must be smaller than or equal to 4.' end if @api_client.config.client_side_validation && !opts[:'beds'].nil? && opts[:'beds'] < 0 fail ArgumentError, 'invalid value for "opts[:"beds"]" when calling ApartmentsApi.apartments_search_rental_listings, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] > 20000 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling ApartmentsApi.apartments_search_rental_listings, must be smaller than or equal to 20000.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 100 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling ApartmentsApi.apartments_search_rental_listings, must be greater than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] > 20000 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling ApartmentsApi.apartments_search_rental_listings, must be smaller than or equal to 20000.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 100 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling ApartmentsApi.apartments_search_rental_listings, must be greater than or equal to 100.' end # resource path local_var_path = '/v1/apartments/search' # query parameters query_params = opts[:query_params] || {} query_params[:'location'] = location query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'beds'] = opts[:'beds'] if !opts[:'beds'].nil? query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil? query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ApartmentsApi.apartments_search_rental_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApartmentsApi#apartments_search_rental_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |