Class: ScrapeBadger::VintedApi
- Inherits:
-
Object
- Object
- ScrapeBadger::VintedApi
- Defined in:
- lib/scrapebadger/api/vinted_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ VintedApi
constructor
A new instance of VintedApi.
-
#vinted_get_item_details(item_id, opts = {}) ⇒ Object
Get item details Get detailed information about a Vinted item.
-
#vinted_get_item_details_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get item details Get detailed information about a Vinted item.
-
#vinted_get_user_profile(user_id, opts = {}) ⇒ Object
Get user profile Get a Vinted user's profile.
-
#vinted_get_user_profile_with_http_info(user_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get user profile Get a Vinted user's profile.
-
#vinted_get_user_s_listed_items(user_id, opts = {}) ⇒ Object
Get user's listed items Get items listed by a Vinted user.
-
#vinted_get_user_s_listed_items_with_http_info(user_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get user's listed items Get items listed by a Vinted user.
-
#vinted_list_colors(opts = {}) ⇒ Object
List colors Get available Vinted colors for filtering.
-
#vinted_list_colors_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List colors Get available Vinted colors for filtering.
-
#vinted_list_item_conditions(opts = {}) ⇒ Object
List item conditions Get available item condition statuses.
-
#vinted_list_item_conditions_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List item conditions Get available item condition statuses.
-
#vinted_list_markets(opts = {}) ⇒ Object
List markets List all supported Vinted markets.
-
#vinted_list_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List markets List all supported Vinted markets.
-
#vinted_search_brands(keyword, opts = {}) ⇒ Object
Search brands Search Vinted brands.
-
#vinted_search_brands_with_http_info(keyword, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search brands Search Vinted brands.
-
#vinted_search_vinted_items(query, opts = {}) ⇒ Object
Search Vinted items Search Vinted catalog items with filters.
-
#vinted_search_vinted_items_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search Vinted items Search Vinted catalog items with filters.
-
#vinted_vinted_scraper_health_check(opts = {}) ⇒ Object
Vinted scraper health check Check health of the Vinted scraper service.
-
#vinted_vinted_scraper_health_check_head(opts = {}) ⇒ Object
Vinted scraper health check Check health of the Vinted scraper service.
-
#vinted_vinted_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Vinted scraper health check Check health of the Vinted scraper service.
-
#vinted_vinted_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Vinted scraper health check Check health of the Vinted scraper service.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#vinted_get_item_details(item_id, opts = {}) ⇒ Object
Get item details Get detailed information about a Vinted item.
28 29 30 31 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 28 def vinted_get_item_details(item_id, opts = {}) data, _status_code, _headers = vinted_get_item_details_with_http_info(item_id, opts) data end |
#vinted_get_item_details_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get item details Get detailed information about a Vinted item.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 39 def vinted_get_item_details_with_http_info(item_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_get_item_details ...' end # verify the required parameter 'item_id' is set if @api_client.config.client_side_validation && item_id.nil? fail ArgumentError, "Missing the required parameter 'item_id' when calling VintedApi.vinted_get_item_details" end # resource path local_var_path = '/v1/vinted/items/{item_id}'.sub('{' + 'item_id' + '}', CGI.escape(item_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_get_item_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_get_item_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_get_user_profile(user_id, opts = {}) ⇒ Object
Get user profile Get a Vinted user's profile.
94 95 96 97 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 94 def vinted_get_user_profile(user_id, opts = {}) data, _status_code, _headers = vinted_get_user_profile_with_http_info(user_id, opts) data end |
#vinted_get_user_profile_with_http_info(user_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get user profile Get a Vinted user's profile.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 105 def vinted_get_user_profile_with_http_info(user_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_get_user_profile ...' end # verify the required parameter 'user_id' is set if @api_client.config.client_side_validation && user_id.nil? fail ArgumentError, "Missing the required parameter 'user_id' when calling VintedApi.vinted_get_user_profile" end # resource path local_var_path = '/v1/vinted/users/{user_id}'.sub('{' + 'user_id' + '}', CGI.escape(user_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_get_user_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_get_user_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_get_user_s_listed_items(user_id, opts = {}) ⇒ Object
Get user's listed items Get items listed by a Vinted user.
162 163 164 165 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 162 def vinted_get_user_s_listed_items(user_id, opts = {}) data, _status_code, _headers = vinted_get_user_s_listed_items_with_http_info(user_id, opts) data end |
#vinted_get_user_s_listed_items_with_http_info(user_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get user's listed items Get items listed by a Vinted user.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 175 def vinted_get_user_s_listed_items_with_http_info(user_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_get_user_s_listed_items ...' end # verify the required parameter 'user_id' is set if @api_client.config.client_side_validation && user_id.nil? fail ArgumentError, "Missing the required parameter 'user_id' when calling VintedApi.vinted_get_user_s_listed_items" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling VintedApi.vinted_get_user_s_listed_items, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 96 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling VintedApi.vinted_get_user_s_listed_items, must be smaller than or equal to 96.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling VintedApi.vinted_get_user_s_listed_items, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/vinted/users/{user_id}/items'.sub('{' + 'user_id' + '}', CGI.escape(user_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_get_user_s_listed_items", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_get_user_s_listed_items\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_list_colors(opts = {}) ⇒ Object
List colors Get available Vinted colors for filtering.
243 244 245 246 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 243 def vinted_list_colors(opts = {}) data, _status_code, _headers = vinted_list_colors_with_http_info(opts) data end |
#vinted_list_colors_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List colors Get available Vinted colors for filtering.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 253 def vinted_list_colors_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_list_colors ...' end # resource path local_var_path = '/v1/vinted/colors' # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_list_colors", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_list_colors\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_list_item_conditions(opts = {}) ⇒ Object
List item conditions Get available item condition statuses.
303 304 305 306 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 303 def vinted_list_item_conditions(opts = {}) data, _status_code, _headers = vinted_list_item_conditions_with_http_info(opts) data end |
#vinted_list_item_conditions_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List item conditions Get available item condition statuses.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 313 def vinted_list_item_conditions_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_list_item_conditions ...' end # resource path local_var_path = '/v1/vinted/statuses' # query parameters query_params = opts[:query_params] || {} query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_list_item_conditions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_list_item_conditions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_list_markets(opts = {}) ⇒ Object
List markets List all supported Vinted markets.
362 363 364 365 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 362 def vinted_list_markets(opts = {}) data, _status_code, _headers = vinted_list_markets_with_http_info(opts) data end |
#vinted_list_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List markets List all supported Vinted markets.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 371 def vinted_list_markets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_list_markets ...' end # resource path local_var_path = '/v1/vinted/markets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_list_markets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_list_markets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_search_brands(keyword, opts = {}) ⇒ Object
Search brands Search Vinted brands.
421 422 423 424 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 421 def vinted_search_brands(keyword, opts = {}) data, _status_code, _headers = vinted_search_brands_with_http_info(keyword, opts) data end |
#vinted_search_brands_with_http_info(keyword, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search brands Search Vinted brands.
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 432 def vinted_search_brands_with_http_info(keyword, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_search_brands ...' end # verify the required parameter 'keyword' is set if @api_client.config.client_side_validation && keyword.nil? fail ArgumentError, "Missing the required parameter 'keyword' when calling VintedApi.vinted_search_brands" end # resource path local_var_path = '/v1/vinted/brands' # query parameters query_params = opts[:query_params] || {} query_params[:'keyword'] = keyword query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_search_brands", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_search_brands\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_search_vinted_items(query, opts = {}) ⇒ Object
Search Vinted items Search Vinted catalog items with filters.
498 499 500 501 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 498 def vinted_search_vinted_items(query, opts = {}) data, _status_code, _headers = vinted_search_vinted_items_with_http_info(query, opts) data end |
#vinted_search_vinted_items_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search Vinted items Search Vinted catalog items with filters.
519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 519 def vinted_search_vinted_items_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_search_vinted_items ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling VintedApi.vinted_search_vinted_items" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling VintedApi.vinted_search_vinted_items, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 96 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling VintedApi.vinted_search_vinted_items, must be smaller than or equal to 96.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling VintedApi.vinted_search_vinted_items, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/vinted/search' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'market'] = opts[:'market'] if !opts[:'market'].nil? query_params[:'seller_country'] = opts[:'seller_country'] if !opts[:'seller_country'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'price_from'] = opts[:'price_from'] if !opts[:'price_from'].nil? query_params[:'price_to'] = opts[:'price_to'] if !opts[:'price_to'].nil? query_params[:'brand_ids'] = opts[:'brand_ids'] if !opts[:'brand_ids'].nil? query_params[:'catalog_ids'] = opts[:'catalog_ids'] if !opts[:'catalog_ids'].nil? query_params[:'color_ids'] = opts[:'color_ids'] if !opts[:'color_ids'].nil? query_params[:'status_ids'] = opts[:'status_ids'] if !opts[:'status_ids'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_search_vinted_items", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_search_vinted_items\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_vinted_scraper_health_check(opts = {}) ⇒ Object
Vinted scraper health check
Check health of the Vinted scraper service. Accepts HEAD so external uptime checkers (UptimeRobot uses HEAD by default for HTTP monitors) don't get a 405 Method Not Allowed.
595 596 597 598 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 595 def vinted_vinted_scraper_health_check(opts = {}) data, _status_code, _headers = vinted_vinted_scraper_health_check_with_http_info(opts) data end |
#vinted_vinted_scraper_health_check_head(opts = {}) ⇒ Object
Vinted scraper health check
Check health of the Vinted scraper service. Accepts HEAD so external uptime checkers (UptimeRobot uses HEAD by default for HTTP monitors) don't get a 405 Method Not Allowed.
652 653 654 655 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 652 def vinted_vinted_scraper_health_check_head(opts = {}) data, _status_code, _headers = vinted_vinted_scraper_health_check_head_with_http_info(opts) data end |
#vinted_vinted_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Vinted scraper health check Check health of the Vinted scraper service. Accepts ``HEAD`` so external uptime checkers (UptimeRobot uses HEAD by default for HTTP monitors) don't get a 405 Method Not Allowed.
661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 661 def vinted_vinted_scraper_health_check_head_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_vinted_scraper_health_check_head ...' end # resource path local_var_path = '/v1/vinted/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_vinted_scraper_health_check_head", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_vinted_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#vinted_vinted_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Vinted scraper health check Check health of the Vinted scraper service. Accepts ``HEAD`` so external uptime checkers (UptimeRobot uses HEAD by default for HTTP monitors) don't get a 405 Method Not Allowed.
604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/scrapebadger/api/vinted_api.rb', line 604 def vinted_vinted_scraper_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VintedApi.vinted_vinted_scraper_health_check ...' end # resource path local_var_path = '/v1/vinted/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"VintedApi.vinted_vinted_scraper_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VintedApi#vinted_vinted_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |