Class: ScrapeBadger::WalmartApi
- Inherits:
-
Object
- Object
- ScrapeBadger::WalmartApi
- Defined in:
- lib/scrapebadger/api/walmart_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ WalmartApi
constructor
A new instance of WalmartApi.
-
#walmart_browse_a_category(path, opts = {}) ⇒ Object
Browse a category Browse a Walmart category.
-
#walmart_browse_a_category_with_http_info(path, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Browse a category Browse a Walmart category.
-
#walmart_deals_rollbacks_and_clearance(opts = {}) ⇒ Object
Deals, rollbacks and clearance Walmart's current deals, rollbacks and clearance.
-
#walmart_deals_rollbacks_and_clearance_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Deals, rollbacks and clearance Walmart's current deals, rollbacks and clearance.
-
#walmart_get_a_seller_s_catalogue(seller_id, query, opts = {}) ⇒ Object
Get a seller's catalogue A marketplace seller's catalogue, scoped by a search term.
-
#walmart_get_a_seller_s_catalogue_with_http_info(seller_id, query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get a seller's catalogue A marketplace seller's catalogue, scoped by a search term.
-
#walmart_get_product_detail(item_id, opts = {}) ⇒ Object
Get product detail Full product detail — price, stock, specs, variants, seller, reviews sample.
-
#walmart_get_product_detail_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get product detail Full product detail — price, stock, specs, variants, seller, reviews sample.
-
#walmart_get_product_reviews(item_id, opts = {}) ⇒ Object
Get product reviews Paginated reviews with the full star histogram.
-
#walmart_get_product_reviews_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get product reviews Paginated reviews with the full star histogram.
-
#walmart_get_seller_profile(seller_id, opts = {}) ⇒ Object
Get seller profile Marketplace seller profile — contact details, address, rating, policies.
-
#walmart_get_seller_profile_with_http_info(seller_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller profile Marketplace seller profile — contact details, address, rating, policies.
-
#walmart_get_store_nearby_stores(store_id, opts = {}) ⇒ Object
Get store + nearby stores Store detail with hours, per-department services, and nearby stores.
-
#walmart_get_store_nearby_stores_with_http_info(store_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get store + nearby stores Store detail with hours, per-department services, and nearby stores.
-
#walmart_list_supported_markets(opts = {}) ⇒ Object
List supported markets Supported Walmart markets.
-
#walmart_list_supported_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List supported markets Supported Walmart markets.
-
#walmart_search_products(query, opts = {}) ⇒ Object
Search products Search walmart.com.
-
#walmart_search_products_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search products Search walmart.com.
-
#walmart_search_suggestions(query, opts = {}) ⇒ Object
Search suggestions Walmart search-box suggestions.
-
#walmart_search_suggestions_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search suggestions Walmart search-box suggestions.
-
#walmart_walmart_scraper_health_check(opts = {}) ⇒ Object
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
-
#walmart_walmart_scraper_health_check_head(opts = {}) ⇒ Object
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
-
#walmart_walmart_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
-
#walmart_walmart_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WalmartApi
Returns a new instance of WalmartApi.
19 20 21 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#walmart_browse_a_category(path, opts = {}) ⇒ Object
Browse a category
Browse a Walmart category. Same result shape as search. No sort: Walmart's browse pages ignore it. Sort on /search instead.
31 32 33 34 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 31 def walmart_browse_a_category(path, opts = {}) data, _status_code, _headers = walmart_browse_a_category_with_http_info(path, opts) data end |
#walmart_browse_a_category_with_http_info(path, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Browse a category Browse a Walmart category. Same result shape as search. No `sort`: Walmart's browse pages ignore it. Sort on `/search` instead.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 45 def walmart_browse_a_category_with_http_info(path, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_browse_a_category ...' end # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? fail ArgumentError, "Missing the required parameter 'path' when calling WalmartApi.walmart_browse_a_category" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 11 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_browse_a_category, must be smaller than or equal to 11.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_browse_a_category, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling WalmartApi.walmart_browse_a_category, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling WalmartApi.walmart_browse_a_category, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/walmart/category' # query parameters query_params = opts[:query_params] || {} query_params[:'path'] = path query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil? query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil? query_params[:'facet'] = opts[:'facet'] if !opts[:'facet'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_browse_a_category", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_browse_a_category\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_deals_rollbacks_and_clearance(opts = {}) ⇒ Object
Deals, rollbacks and clearance Walmart's current deals, rollbacks and clearance.
121 122 123 124 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 121 def walmart_deals_rollbacks_and_clearance(opts = {}) data, _status_code, _headers = walmart_deals_rollbacks_and_clearance_with_http_info(opts) data end |
#walmart_deals_rollbacks_and_clearance_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Deals, rollbacks and clearance Walmart's current deals, rollbacks and clearance.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 133 def walmart_deals_rollbacks_and_clearance_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_deals_rollbacks_and_clearance ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 11 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_deals_rollbacks_and_clearance, must be smaller than or equal to 11.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_deals_rollbacks_and_clearance, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling WalmartApi.walmart_deals_rollbacks_and_clearance, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling WalmartApi.walmart_deals_rollbacks_and_clearance, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/walmart/deals' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil? query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_deals_rollbacks_and_clearance", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_deals_rollbacks_and_clearance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_get_a_seller_s_catalogue(seller_id, query, opts = {}) ⇒ Object
Get a seller's catalogue A marketplace seller's catalogue, scoped by a search term.
204 205 206 207 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 204 def walmart_get_a_seller_s_catalogue(seller_id, query, opts = {}) data, _status_code, _headers = walmart_get_a_seller_s_catalogue_with_http_info(seller_id, query, opts) data end |
#walmart_get_a_seller_s_catalogue_with_http_info(seller_id, query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get a seller's catalogue A marketplace seller's catalogue, scoped by a search term.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 217 def walmart_get_a_seller_s_catalogue_with_http_info(seller_id, query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_get_a_seller_s_catalogue ...' end # verify the required parameter 'seller_id' is set if @api_client.config.client_side_validation && seller_id.nil? fail ArgumentError, "Missing the required parameter 'seller_id' when calling WalmartApi.walmart_get_a_seller_s_catalogue" end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling WalmartApi.walmart_get_a_seller_s_catalogue" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 10 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_get_a_seller_s_catalogue, must be smaller than or equal to 10.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_get_a_seller_s_catalogue, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/walmart/sellers/{seller_id}/products'.sub('{' + 'seller_id' + '}', CGI.escape(seller_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_get_a_seller_s_catalogue", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_get_a_seller_s_catalogue\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_get_product_detail(item_id, opts = {}) ⇒ Object
Get product detail Full product detail — price, stock, specs, variants, seller, reviews sample.
285 286 287 288 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 285 def walmart_get_product_detail(item_id, opts = {}) data, _status_code, _headers = walmart_get_product_detail_with_http_info(item_id, opts) data end |
#walmart_get_product_detail_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get product detail Full product detail — price, stock, specs, variants, seller, reviews sample.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 295 def walmart_get_product_detail_with_http_info(item_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_get_product_detail ...' end # verify the required parameter 'item_id' is set if @api_client.config.client_side_validation && item_id.nil? fail ArgumentError, "Missing the required parameter 'item_id' when calling WalmartApi.walmart_get_product_detail" end # resource path local_var_path = '/v1/walmart/products/{item_id}'.sub('{' + 'item_id' + '}', CGI.escape(item_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_get_product_detail", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_get_product_detail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_get_product_reviews(item_id, opts = {}) ⇒ Object
Get product reviews Paginated reviews with the full star histogram. 10 per page.
350 351 352 353 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 350 def walmart_get_product_reviews(item_id, opts = {}) data, _status_code, _headers = walmart_get_product_reviews_with_http_info(item_id, opts) data end |
#walmart_get_product_reviews_with_http_info(item_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get product reviews Paginated reviews with the full star histogram. 10 per page.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 362 def walmart_get_product_reviews_with_http_info(item_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_get_product_reviews ...' end # verify the required parameter 'item_id' is set if @api_client.config.client_side_validation && item_id.nil? fail ArgumentError, "Missing the required parameter 'item_id' when calling WalmartApi.walmart_get_product_reviews" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 100 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_get_product_reviews, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_get_product_reviews, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/walmart/products/{item_id}/reviews'.sub('{' + 'item_id' + '}', CGI.escape(item_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_get_product_reviews", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_get_product_reviews\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_get_seller_profile(seller_id, opts = {}) ⇒ Object
Get seller profile
Marketplace seller profile — contact details, address, rating, policies. No page: adding one makes Walmart's own SSR throw. Use /sellers/{id}/products for the catalogue.
425 426 427 428 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 425 def walmart_get_seller_profile(seller_id, opts = {}) data, _status_code, _headers = walmart_get_seller_profile_with_http_info(seller_id, opts) data end |
#walmart_get_seller_profile_with_http_info(seller_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get seller profile Marketplace seller profile — contact details, address, rating, policies. No `page`: adding one makes Walmart's own SSR throw. Use `/sellers/id/products` for the catalogue.
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 435 def walmart_get_seller_profile_with_http_info(seller_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_get_seller_profile ...' end # verify the required parameter 'seller_id' is set if @api_client.config.client_side_validation && seller_id.nil? fail ArgumentError, "Missing the required parameter 'seller_id' when calling WalmartApi.walmart_get_seller_profile" end # resource path local_var_path = '/v1/walmart/sellers/{seller_id}'.sub('{' + 'seller_id' + '}', CGI.escape(seller_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_get_seller_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_get_seller_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_get_store_nearby_stores(store_id, opts = {}) ⇒ Object
Get store + nearby stores Store detail with hours, per-department services, and nearby stores.
488 489 490 491 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 488 def walmart_get_store_nearby_stores(store_id, opts = {}) data, _status_code, _headers = walmart_get_store_nearby_stores_with_http_info(store_id, opts) data end |
#walmart_get_store_nearby_stores_with_http_info(store_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get store + nearby stores Store detail with hours, per-department services, and nearby stores.
498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 498 def walmart_get_store_nearby_stores_with_http_info(store_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_get_store_nearby_stores ...' end # verify the required parameter 'store_id' is set if @api_client.config.client_side_validation && store_id.nil? fail ArgumentError, "Missing the required parameter 'store_id' when calling WalmartApi.walmart_get_store_nearby_stores" end # resource path local_var_path = '/v1/walmart/stores/{store_id}'.sub('{' + 'store_id' + '}', CGI.escape(store_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_get_store_nearby_stores", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_get_store_nearby_stores\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_list_supported_markets(opts = {}) ⇒ Object
List supported markets Supported Walmart markets.
550 551 552 553 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 550 def walmart_list_supported_markets(opts = {}) data, _status_code, _headers = walmart_list_supported_markets_with_http_info(opts) data end |
#walmart_list_supported_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List supported markets Supported Walmart markets.
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 559 def walmart_list_supported_markets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_list_supported_markets ...' end # resource path local_var_path = '/v1/walmart/markets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_list_supported_markets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_list_supported_markets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_search_products(query, opts = {}) ⇒ Object
Search products Search walmart.com. ~40-60 organic products per page; ad tiles are dropped.
613 614 615 616 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 613 def walmart_search_products(query, opts = {}) data, _status_code, _headers = walmart_search_products_with_http_info(query, opts) data end |
#walmart_search_products_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search products Search walmart.com. ~40-60 organic products per page; ad tiles are dropped.
628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 628 def walmart_search_products_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_search_products ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling WalmartApi.walmart_search_products" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 10 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_search_products, must be smaller than or equal to 10.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalmartApi.walmart_search_products, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'min_price'].nil? && opts[:'min_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"min_price"]" when calling WalmartApi.walmart_search_products, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'max_price'].nil? && opts[:'max_price'] < 0 fail ArgumentError, 'invalid value for "opts[:"max_price"]" when calling WalmartApi.walmart_search_products, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/walmart/search' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'min_price'] = opts[:'min_price'] if !opts[:'min_price'].nil? query_params[:'max_price'] = opts[:'max_price'] if !opts[:'max_price'].nil? query_params[:'facet'] = opts[:'facet'] if !opts[:'facet'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_search_products", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_search_products\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_search_suggestions(query, opts = {}) ⇒ Object
Search suggestions Walmart search-box suggestions.
703 704 705 706 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 703 def walmart_search_suggestions(query, opts = {}) data, _status_code, _headers = walmart_search_suggestions_with_http_info(query, opts) data end |
#walmart_search_suggestions_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search suggestions Walmart search-box suggestions.
713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 713 def walmart_search_suggestions_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_search_suggestions ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling WalmartApi.walmart_search_suggestions" end # resource path local_var_path = '/v1/walmart/autocomplete' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_search_suggestions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_search_suggestions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_walmart_scraper_health_check(opts = {}) ⇒ Object
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
766 767 768 769 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 766 def walmart_walmart_scraper_health_check(opts = {}) data, _status_code, _headers = walmart_walmart_scraper_health_check_with_http_info(opts) data end |
#walmart_walmart_scraper_health_check_head(opts = {}) ⇒ Object
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
823 824 825 826 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 823 def walmart_walmart_scraper_health_check_head(opts = {}) data, _status_code, _headers = walmart_walmart_scraper_health_check_head_with_http_info(opts) data end |
#walmart_walmart_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 832 def walmart_walmart_scraper_health_check_head_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_walmart_scraper_health_check_head ...' end # resource path local_var_path = '/v1/walmart/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_walmart_scraper_health_check_head", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_walmart_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#walmart_walmart_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Walmart scraper health check Check health of the Walmart scraper service (accepts HEAD for UptimeRobot).
775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 |
# File 'lib/scrapebadger/api/walmart_api.rb', line 775 def walmart_walmart_scraper_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalmartApi.walmart_walmart_scraper_health_check ...' end # resource path local_var_path = '/v1/walmart/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"WalmartApi.walmart_walmart_scraper_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalmartApi#walmart_walmart_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |