Class: ScrapeBadger::YandexApi
- Inherits:
-
Object
- Object
- ScrapeBadger::YandexApi
- Defined in:
- lib/scrapebadger/api/yandex_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ YandexApi
constructor
A new instance of YandexApi.
-
#yandex_image_search(query, opts = {}) ⇒ Object
Image search Search Yandex Images by text — thumbnail, full-res URL, dimensions, source page.
-
#yandex_image_search_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Image search Search Yandex Images by text — thumbnail, full-res URL, dimensions, source page.
-
#yandex_list_supported_markets(opts = {}) ⇒ Object
List supported markets Supported Yandex markets (domains, default region and language).
-
#yandex_list_supported_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List supported markets Supported Yandex markets (domains, default region and language).
-
#yandex_reverse_image_search(image_url, opts = {}) ⇒ Object
Reverse image search Reverse image search by URL — hosting pages, similar images, tags, other sizes.
-
#yandex_reverse_image_search_with_http_info(image_url, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Reverse image search Reverse image search by URL — hosting pages, similar images, tags, other sizes.
-
#yandex_web_search(query, opts = {}) ⇒ Object
Web search Search Yandex web results — organic results, ads, displayed URLs, snippets.
-
#yandex_web_search_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Web search Search Yandex web results — organic results, ads, displayed URLs, snippets.
-
#yandex_yandex_scraper_health_check(opts = {}) ⇒ Object
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
-
#yandex_yandex_scraper_health_check_head(opts = {}) ⇒ Object
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
-
#yandex_yandex_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
-
#yandex_yandex_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#yandex_image_search(query, opts = {}) ⇒ Object
Image search Search Yandex Images by text — thumbnail, full-res URL, dimensions, source page.
29 30 31 32 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 29 def yandex_image_search(query, opts = {}) data, _status_code, _headers = yandex_image_search_with_http_info(query, opts) data end |
#yandex_image_search_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Image search Search Yandex Images by text — thumbnail, full-res URL, dimensions, source page.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 41 def yandex_image_search_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: YandexApi.yandex_image_search ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling YandexApi.yandex_image_search" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 25 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling YandexApi.yandex_image_search, must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling YandexApi.yandex_image_search, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/yandex/images/search' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"YandexApi.yandex_image_search", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: YandexApi#yandex_image_search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#yandex_list_supported_markets(opts = {}) ⇒ Object
List supported markets Supported Yandex markets (domains, default region and language).
104 105 106 107 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 104 def yandex_list_supported_markets(opts = {}) data, _status_code, _headers = yandex_list_supported_markets_with_http_info(opts) data end |
#yandex_list_supported_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List supported markets Supported Yandex markets (domains, default region and language).
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 113 def yandex_list_supported_markets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: YandexApi.yandex_list_supported_markets ...' end # resource path local_var_path = '/v1/yandex/markets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"YandexApi.yandex_list_supported_markets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: YandexApi#yandex_list_supported_markets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#yandex_reverse_image_search(image_url, opts = {}) ⇒ Object
Reverse image search Reverse image search by URL — hosting pages, similar images, tags, other sizes.
163 164 165 166 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 163 def yandex_reverse_image_search(image_url, opts = {}) data, _status_code, _headers = yandex_reverse_image_search_with_http_info(image_url, opts) data end |
#yandex_reverse_image_search_with_http_info(image_url, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Reverse image search Reverse image search by URL — hosting pages, similar images, tags, other sizes.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 174 def yandex_reverse_image_search_with_http_info(image_url, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: YandexApi.yandex_reverse_image_search ...' end # verify the required parameter 'image_url' is set if @api_client.config.client_side_validation && image_url.nil? fail ArgumentError, "Missing the required parameter 'image_url' when calling YandexApi.yandex_reverse_image_search" end # resource path local_var_path = '/v1/yandex/images/reverse' # query parameters query_params = opts[:query_params] || {} query_params[:'image_url'] = image_url query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"YandexApi.yandex_reverse_image_search", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: YandexApi#yandex_reverse_image_search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#yandex_web_search(query, opts = {}) ⇒ Object
Web search Search Yandex web results — organic results, ads, displayed URLs, snippets.
233 234 235 236 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 233 def yandex_web_search(query, opts = {}) data, _status_code, _headers = yandex_web_search_with_http_info(query, opts) data end |
#yandex_web_search_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Web search Search Yandex web results — organic results, ads, displayed URLs, snippets.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 247 def yandex_web_search_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: YandexApi.yandex_web_search ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling YandexApi.yandex_web_search" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 25 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling YandexApi.yandex_web_search, must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling YandexApi.yandex_web_search, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/yandex/search' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query query_params[:'domain'] = opts[:'domain'] if !opts[:'domain'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'lr'] = opts[:'lr'] if !opts[:'lr'].nil? query_params[:'lang'] = opts[:'lang'] if !opts[:'lang'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"YandexApi.yandex_web_search", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: YandexApi#yandex_web_search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#yandex_yandex_scraper_health_check(opts = {}) ⇒ Object
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
312 313 314 315 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 312 def yandex_yandex_scraper_health_check(opts = {}) data, _status_code, _headers = yandex_yandex_scraper_health_check_with_http_info(opts) data end |
#yandex_yandex_scraper_health_check_head(opts = {}) ⇒ Object
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
369 370 371 372 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 369 def yandex_yandex_scraper_health_check_head(opts = {}) data, _status_code, _headers = yandex_yandex_scraper_health_check_head_with_http_info(opts) data end |
#yandex_yandex_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 378 def yandex_yandex_scraper_health_check_head_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: YandexApi.yandex_yandex_scraper_health_check_head ...' end # resource path local_var_path = '/v1/yandex/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"YandexApi.yandex_yandex_scraper_health_check_head", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: YandexApi#yandex_yandex_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#yandex_yandex_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Yandex scraper health check Check health of the Yandex scraper service (accepts HEAD for UptimeRobot).
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/scrapebadger/api/yandex_api.rb', line 321 def yandex_yandex_scraper_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: YandexApi.yandex_yandex_scraper_health_check ...' end # resource path local_var_path = '/v1/yandex/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"YandexApi.yandex_yandex_scraper_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: YandexApi#yandex_yandex_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |