Class: ScrapeBadger::ZillowApi
- Inherits:
-
Object
- Object
- ScrapeBadger::ZillowApi
- Defined in:
- lib/scrapebadger/api/zillow_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ZillowApi
constructor
A new instance of ZillowApi.
-
#zillow_get_agent_profile_listings(opts = {}) ⇒ Object
Get agent profile + listings Get a Zillow professional's profile and their active listings.
-
#zillow_get_agent_profile_listings_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get agent profile + listings Get a Zillow professional's profile and their active listings.
-
#zillow_get_property_detail(zpid, opts = {}) ⇒ Object
Get property detail Get a single Zillow property's full detail by zpid.
-
#zillow_get_property_detail_by_url(url, opts = {}) ⇒ Object
Get property detail by URL Get a single Zillow property's full detail by its homedetails URL.
-
#zillow_get_property_detail_by_url_with_http_info(url, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail by URL Get a single Zillow property's full detail by its homedetails URL.
-
#zillow_get_property_detail_with_http_info(zpid, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail Get a single Zillow property's full detail by zpid.
-
#zillow_list_coverage_markets(opts = {}) ⇒ Object
List coverage markets List Zillow coverage regions (US + Canada).
-
#zillow_list_coverage_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List coverage markets List Zillow coverage regions (US + Canada).
-
#zillow_region_address_suggestions(query, opts = {}) ⇒ Object
Region/address suggestions Resolve a search term to Zillow regions/addresses.
-
#zillow_region_address_suggestions_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Region/address suggestions Resolve a search term to Zillow regions/addresses.
-
#zillow_search_properties(location, opts = {}) ⇒ Object
Search properties Search Zillow for for-sale / for-rent / recently-sold properties.
-
#zillow_search_properties_with_http_info(location, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search properties Search Zillow for for-sale / for-rent / recently-sold properties.
-
#zillow_zillow_scraper_health_check(opts = {}) ⇒ Object
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
-
#zillow_zillow_scraper_health_check_head(opts = {}) ⇒ Object
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
-
#zillow_zillow_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
-
#zillow_zillow_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#zillow_get_agent_profile_listings(opts = {}) ⇒ Object
Get agent profile + listings Get a Zillow professional's profile and their active listings.
28 29 30 31 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 28 def zillow_get_agent_profile_listings(opts = {}) data, _status_code, _headers = zillow_get_agent_profile_listings_with_http_info(opts) data end |
#zillow_get_agent_profile_listings_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get agent profile + listings Get a Zillow professional's profile and their active listings.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 39 def zillow_get_agent_profile_listings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_get_agent_profile_listings ...' end # resource path local_var_path = '/v1/zillow/agent' # query parameters query_params = opts[:query_params] || {} query_params[:'username'] = opts[:'username'] if !opts[:'username'].nil? query_params[:'url'] = opts[:'url'] if !opts[:'url'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_get_agent_profile_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_get_agent_profile_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#zillow_get_property_detail(zpid, opts = {}) ⇒ Object
Get property detail Get a single Zillow property's full detail by zpid.
90 91 92 93 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 90 def zillow_get_property_detail(zpid, opts = {}) data, _status_code, _headers = zillow_get_property_detail_with_http_info(zpid, opts) data end |
#zillow_get_property_detail_by_url(url, opts = {}) ⇒ Object
Get property detail by URL Get a single Zillow property's full detail by its homedetails URL.
153 154 155 156 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 153 def zillow_get_property_detail_by_url(url, opts = {}) data, _status_code, _headers = zillow_get_property_detail_by_url_with_http_info(url, opts) data end |
#zillow_get_property_detail_by_url_with_http_info(url, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail by URL Get a single Zillow property's full detail by its homedetails URL.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 163 def zillow_get_property_detail_by_url_with_http_info(url, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_get_property_detail_by_url ...' end # verify the required parameter 'url' is set if @api_client.config.client_side_validation && url.nil? fail ArgumentError, "Missing the required parameter 'url' when calling ZillowApi.zillow_get_property_detail_by_url" end # resource path local_var_path = '/v1/zillow/property' # query parameters query_params = opts[:query_params] || {} query_params[:'url'] = url # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_get_property_detail_by_url", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_get_property_detail_by_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#zillow_get_property_detail_with_http_info(zpid, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get property detail Get a single Zillow property's full detail by zpid.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 100 def zillow_get_property_detail_with_http_info(zpid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_get_property_detail ...' end # verify the required parameter 'zpid' is set if @api_client.config.client_side_validation && zpid.nil? fail ArgumentError, "Missing the required parameter 'zpid' when calling ZillowApi.zillow_get_property_detail" end # resource path local_var_path = '/v1/zillow/property/{zpid}'.sub('{' + 'zpid' + '}', CGI.escape(zpid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_get_property_detail", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_get_property_detail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#zillow_list_coverage_markets(opts = {}) ⇒ Object
List coverage markets List Zillow coverage regions (US + Canada).
216 217 218 219 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 216 def zillow_list_coverage_markets(opts = {}) data, _status_code, _headers = zillow_list_coverage_markets_with_http_info(opts) data end |
#zillow_list_coverage_markets_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
List coverage markets List Zillow coverage regions (US + Canada).
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 225 def zillow_list_coverage_markets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_list_coverage_markets ...' end # resource path local_var_path = '/v1/zillow/markets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_list_coverage_markets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_list_coverage_markets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#zillow_region_address_suggestions(query, opts = {}) ⇒ Object
Region/address suggestions Resolve a search term to Zillow regions/addresses.
274 275 276 277 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 274 def zillow_region_address_suggestions(query, opts = {}) data, _status_code, _headers = zillow_region_address_suggestions_with_http_info(query, opts) data end |
#zillow_region_address_suggestions_with_http_info(query, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Region/address suggestions Resolve a search term to Zillow regions/addresses.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 284 def zillow_region_address_suggestions_with_http_info(query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_region_address_suggestions ...' end # verify the required parameter 'query' is set if @api_client.config.client_side_validation && query.nil? fail ArgumentError, "Missing the required parameter 'query' when calling ZillowApi.zillow_region_address_suggestions" end # resource path local_var_path = '/v1/zillow/autocomplete' # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = query # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_region_address_suggestions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_region_address_suggestions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#zillow_search_properties(location, opts = {}) ⇒ Object
Search properties Search Zillow for for-sale / for-rent / recently-sold properties.
359 360 361 362 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 359 def zillow_search_properties(location, opts = {}) data, _status_code, _headers = zillow_search_properties_with_http_info(location, opts) data end |
#zillow_search_properties_with_http_info(location, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Search properties Search Zillow for for-sale / for-rent / recently-sold properties.
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 390 def zillow_search_properties_with_http_info(location, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_search_properties ...' end # verify the required parameter 'location' is set if @api_client.config.client_side_validation && location.nil? fail ArgumentError, "Missing the required parameter 'location' when calling ZillowApi.zillow_search_properties" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 20 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ZillowApi.zillow_search_properties, must be smaller than or equal to 20.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'price_min'].nil? && opts[:'price_min'] < 0 fail ArgumentError, 'invalid value for "opts[:"price_min"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'price_max'].nil? && opts[:'price_max'] < 0 fail ArgumentError, 'invalid value for "opts[:"price_max"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'beds_min'].nil? && opts[:'beds_min'] > 10 fail ArgumentError, 'invalid value for "opts[:"beds_min"]" when calling ZillowApi.zillow_search_properties, must be smaller than or equal to 10.' end if @api_client.config.client_side_validation && !opts[:'beds_min'].nil? && opts[:'beds_min'] < 0 fail ArgumentError, 'invalid value for "opts[:"beds_min"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'baths_min'].nil? && opts[:'baths_min'] > 10 fail ArgumentError, 'invalid value for "opts[:"baths_min"]" when calling ZillowApi.zillow_search_properties, must be smaller than or equal to 10.' end if @api_client.config.client_side_validation && !opts[:'baths_min'].nil? && opts[:'baths_min'] < 0 fail ArgumentError, 'invalid value for "opts[:"baths_min"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'sqft_min'].nil? && opts[:'sqft_min'] < 0 fail ArgumentError, 'invalid value for "opts[:"sqft_min"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'sqft_max'].nil? && opts[:'sqft_max'] < 0 fail ArgumentError, 'invalid value for "opts[:"sqft_max"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'lot_min'].nil? && opts[:'lot_min'] < 0 fail ArgumentError, 'invalid value for "opts[:"lot_min"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'lot_max'].nil? && opts[:'lot_max'] < 0 fail ArgumentError, 'invalid value for "opts[:"lot_max"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'year_built_min'].nil? && opts[:'year_built_min'] < 1800 fail ArgumentError, 'invalid value for "opts[:"year_built_min"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 1800.' end if @api_client.config.client_side_validation && !opts[:'year_built_max'].nil? && opts[:'year_built_max'] < 1800 fail ArgumentError, 'invalid value for "opts[:"year_built_max"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 1800.' end if @api_client.config.client_side_validation && !opts[:'hoa_max'].nil? && opts[:'hoa_max'] < 0 fail ArgumentError, 'invalid value for "opts[:"hoa_max"]" when calling ZillowApi.zillow_search_properties, must be greater than or equal to 0.' end # resource path local_var_path = '/v1/zillow/search' # query parameters query_params = opts[:query_params] || {} query_params[:'location'] = location query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'price_min'] = opts[:'price_min'] if !opts[:'price_min'].nil? query_params[:'price_max'] = opts[:'price_max'] if !opts[:'price_max'].nil? query_params[:'beds_min'] = opts[:'beds_min'] if !opts[:'beds_min'].nil? query_params[:'baths_min'] = opts[:'baths_min'] if !opts[:'baths_min'].nil? query_params[:'home_type'] = opts[:'home_type'] if !opts[:'home_type'].nil? query_params[:'sqft_min'] = opts[:'sqft_min'] if !opts[:'sqft_min'].nil? query_params[:'sqft_max'] = opts[:'sqft_max'] if !opts[:'sqft_max'].nil? query_params[:'lot_min'] = opts[:'lot_min'] if !opts[:'lot_min'].nil? query_params[:'lot_max'] = opts[:'lot_max'] if !opts[:'lot_max'].nil? query_params[:'year_built_min'] = opts[:'year_built_min'] if !opts[:'year_built_min'].nil? query_params[:'year_built_max'] = opts[:'year_built_max'] if !opts[:'year_built_max'].nil? query_params[:'hoa_max'] = opts[:'hoa_max'] if !opts[:'hoa_max'].nil? query_params[:'keywords'] = opts[:'keywords'] if !opts[:'keywords'].nil? query_params[:'days_on'] = opts[:'days_on'] if !opts[:'days_on'].nil? query_params[:'north'] = opts[:'north'] if !opts[:'north'].nil? query_params[:'south'] = opts[:'south'] if !opts[:'south'].nil? query_params[:'east'] = opts[:'east'] if !opts[:'east'].nil? query_params[:'west'] = opts[:'west'] if !opts[:'west'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_search_properties", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_search_properties\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#zillow_zillow_scraper_health_check(opts = {}) ⇒ Object
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
524 525 526 527 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 524 def zillow_zillow_scraper_health_check(opts = {}) data, _status_code, _headers = zillow_zillow_scraper_health_check_with_http_info(opts) data end |
#zillow_zillow_scraper_health_check_head(opts = {}) ⇒ Object
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
581 582 583 584 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 581 def zillow_zillow_scraper_health_check_head(opts = {}) data, _status_code, _headers = zillow_zillow_scraper_health_check_head_with_http_info(opts) data end |
#zillow_zillow_scraper_health_check_head_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 590 def zillow_zillow_scraper_health_check_head_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_zillow_scraper_health_check_head ...' end # resource path local_var_path = '/v1/zillow/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_zillow_scraper_health_check_head", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_zillow_scraper_health_check_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#zillow_zillow_scraper_health_check_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Zillow scraper health check Check health of the Zillow scraper service (accepts HEAD for UptimeRobot).
533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 |
# File 'lib/scrapebadger/api/zillow_api.rb', line 533 def zillow_zillow_scraper_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZillowApi.zillow_zillow_scraper_health_check ...' end # resource path local_var_path = '/v1/zillow/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ZillowApi.zillow_zillow_scraper_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZillowApi#zillow_zillow_scraper_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |